@@ -46,6 +46,45 @@ options:
     description:
       - LSM profile.
     type: str
+  device_id:
+    description:
+      - Device ID.
+    type: str
+    version_added: "6.3.0"
+  dynamic_objects:
+    description:
+      - Dynamic Objects.
+    type: list
+    elements: dict
+    version_added: "6.3.0"
+    suboptions:
+      name:
+        description:
+          - Object name. Must be unique in the domain.
+        type: str
+      resolved_ip_addresses:
+        description:
+          - Single IP-address or a range of addresses.
+        type: list
+        elements: dict
+        suboptions:
+          ipv4_address:
+            description:
+              - IPv4 Address.
+            type: str
+          ipv4_address_range:
+            description:
+              - IPv4 Address range.
+            type: dict
+            suboptions:
+              from_ipv4_address:
+                description:
+                  - First IPv4 address of the IP address range.
+                type: str
+              to_ipv4_address:
+                description:
+                  - Last IPv4 address of the IP address range.
+                type: str
   provisioning_settings:
     description:
       - Provisioning settings.
@@ -75,6 +114,37 @@ options:
           - One-time password. When one-time password is provided without ip-address- trusted communication is automatically initiated  when the
             gateway connects to the Security Management server for the first time.
         type: str
+  topology:
+    description:
+      - Topology.
+    type: dict
+    version_added: "6.3.0"
+    suboptions:
+      manual_vpn_domain:
+        description:
+          - A list of IP-addresses ranges, defined the VPN community network.
+          - This field is relevant only when 'manual' option of vpn-domain is checked.
+        type: list
+        elements: dict
+        suboptions:
+          comments:
+            description:
+              - Comments string.
+            type: str
+          from_ipv4_address:
+            description:
+              - First IPv4 address of the IP address range.
+            type: str
+          to_ipv4_address:
+            description:
+              - Last IPv4 address of the IP address range.
+            type: str
+      vpn_domain:
+        description:
+          - VPN Domain type. 'external-interfaces-only' is relevnt only for Gaia devices.
+            'hide-behind-gateway-external-ip-address' is relevant only for SMB devices.
+        type: str
+        choices: ['not-defined', 'external-ip-addresses-only', 'hide-behind-gateway-external-ip-address', 'all-ip-addresses-behind-the-gateway', 'manual']
   color:
     description:
       - Color of the object. Should be one of existing colors.
@@ -92,6 +162,12 @@ options:
         representation of the object.
     type: str
     choices: ['uid', 'standard', 'full']
+  tags:
+    description:
+      - Collection of tag identifiers.
+    type: list
+    elements: str
+    version_added: "6.3.0"
   ignore_warnings:
     description:
       - Apply changes ignoring warnings.
@@ -152,6 +228,17 @@ def main():
     argument_spec = dict(
         name=dict(type="str", required=True),
         security_profile=dict(type="str"),
+        device_id=dict(type='str'),
+        dynamic_objects=dict(type='list', elements="dict", options=dict(
+            name=dict(type='str'),
+            resolved_ip_addresses=dict(type='list', elements="dict", options=dict(
+                ipv4_address=dict(type='str'),
+                ipv4_address_range=dict(type='dict', options=dict(
+                    from_ipv4_address=dict(type='str'),
+                    to_ipv4_address=dict(type='str')
+                ))
+            ))
+        )),
         provisioning_settings=dict(
             type="dict", options=dict(provisioning_profile=dict(type="str"))
         ),
@@ -165,6 +252,18 @@ def main():
                 one_time_password=dict(type="str", no_log=True),
             ),
         ),
+        topology=dict(type='dict', options=dict(
+            manual_vpn_domain=dict(type='list', elements="dict", options=dict(
+                comments=dict(type='str'),
+                from_ipv4_address=dict(type='str'),
+                to_ipv4_address=dict(type='str')
+            )),
+            vpn_domain=dict(type='str', choices=['not-defined',
+                                                 'external-ip-addresses-only',
+                                                 'hide-behind-gateway-external-ip-address',
+                                                 'all-ip-addresses-behind-the-gateway',
+                                                 'manual'])
+        )),
         color=dict(
             type="str",
             choices=[
@@ -208,6 +307,7 @@ def main():
         ),
         comments=dict(type="str"),
         details_level=dict(type="str", choices=["uid", "standard", "full"]),
+        tags=dict(type="list", elements="str"),
         ignore_warnings=dict(type="bool"),
         ignore_errors=dict(type="bool"),
     )
