@@ -15,6 +15,8 @@
 # Copyright: (c) 2020, Anvitha Jain (@anvitha-jain) <anvjain@cisco.com>
 # Copyright: (c) 2023, Gaspard Micol (@gmicol) <gmicol@cisco.com>
 # Copyright: (c) 2023, Shreyas Srish (@shrsr) <ssrish@cisco.com>
+# Copyright: (c) 2023, Tim Cragg (@timcragg) <tcragg@cisco.com>
+# Copyright: (c) 2024, Samita Bhattacharjee (@samiib) <samitab@cisco.com>
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without modification,
@@ -134,6 +136,12 @@ def aci_argument_spec():
         use_ssl=dict(type="bool", fallback=(env_fallback, ["ACI_USE_SSL"])),
         validate_certs=dict(type="bool", fallback=(env_fallback, ["ACI_VALIDATE_CERTS"])),
         output_path=dict(type="str", fallback=(env_fallback, ["ACI_OUTPUT_PATH"])),
+        suppress_verification=dict(
+            type="bool",
+            aliases=["no_verification", "no_verify", "suppress_verify", "ignore_verify", "ignore_verification"],
+            fallback=(env_fallback, ["ACI_SUPPRESS_VERIFICATION"]),
+        ),
+        suppress_previous=dict(type="bool", aliases=["no_previous", "ignore_previous"], fallback=(env_fallback, ["ACI_SUPPRESS_PREVIOUS"])),
     )
 
 
@@ -315,6 +323,69 @@ def ospf_spec():
     )
 
 
+def integrate_url(httpapi_url, local_path):
+    parse_url = urlparse(httpapi_url)
+    return {"protocol": parse_url.scheme, "host": parse_url.netloc, "path": local_path}
+
+
+def action_rule_set_comm_spec():
+    return dict(
+        community=dict(type="str"),
+        criteria=dict(type="str", choices=["append", "none", "replace"]),
+    )
+
+
+def action_rule_set_dampening_spec():
+    return dict(
+        half_life=dict(type="int"),
+        max_suppress_time=dict(type="int"),
+        reuse=dict(type="int"),
+        suppress=dict(type="int"),
+    )
+
+
+def associated_netflow_exporter_epg_spec():
+    return dict(
+        tenant=dict(type="str"),
+        ap=dict(type="str"),
+        epg=dict(type="str"),
+    )
+
+
+def associated_netflow_exporter_extepg_spec():
+    return dict(
+        tenant=dict(type="str"),
+        l3out=dict(type="str"),
+        extepg=dict(type="str"),
+    )
+
+
+def associated_netflow_exporter_vrf_spec():
+    return dict(
+        tenant=dict(type="str"),
+        vrf=dict(type="str"),
+    )
+
+
+def pim_interface_profile_spec():
+    return dict(
+        tenant=dict(type="str", aliases=["tenant_name"]),
+        pim=dict(type="str", aliases=["pim_interface_policy", "name"]),
+    )
+
+
+def igmp_interface_profile_spec():
+    return dict(tenant=dict(type="str", aliases=["tenant_name"]), igmp=dict(type="str", aliases=["igmp_interface_policy", "name"]))
+
+
+def storm_control_policy_rate_spec():
+    return dict(
+        rate=dict(type="str"),
+        burst_rate=dict(type="str"),
+        rate_type=dict(type="str", choices=["percentage", "pps"], required=True),
+    )
+
+
 class ACIModule(object):
     def __init__(self, module):
         self.module = module
@@ -351,12 +422,21 @@ class ACIModule(object):
         self.imdata = None
         self.totalCount = None
 
+        # get no verify flag
+        self.suppress_verification = self.params.get("suppress_verification")
+
+        # get suppress previous flag
+        self.suppress_previous = self.params.get("suppress_previous")
+
         # Ensure protocol is set
         self.define_protocol()
 
         # Set Connection plugin
         self.set_connection()
 
+        # Get the current working directory
+        self.params["working_directory"] = os.getcwd()
+
         if self.module._debug:
             self.module.warn("Enable debug output because ANSIBLE_DEBUG was set.")
             self.params["output_level"] = "debug"
@@ -410,7 +490,7 @@ class ACIModule(object):
         """Set protocol based on use_ssl parameter"""
 
         # Set protocol for further use
-        self.params["protocol"] = "https" if self.params.get("use_ssl", True) else "http"
+        self.params["protocol"] = "https" if self.params.get("use_ssl") or self.params.get("use_ssl") is None else "http"
 
     def set_connection(self):
         if self.connection is None and self.module._socket_path:
@@ -424,7 +504,7 @@ class ACIModule(object):
         payload = {
             "aaaUser": {
                 "attributes": {
-                    "name": self.params.get("username", "admin"),
+                    "name": "admin" if self.params.get("username") is None else self.params.get("username"),
                     "pwd": self.params.get("password"),
                 }
             }
@@ -500,7 +580,7 @@ class ACIModule(object):
                 )
 
         if self.params.get("certificate_name") is None:
-            self.params["certificate_name"] = self.params.get("username", "admin")
+            self.params["certificate_name"] = "admin" if self.params.get("username") is None else self.params.get("username")
         # NOTE: ACI documentation incorrectly adds a space between method and path
         sig_request = method + path + payload
         if HAS_CRYPTOGRAPHY:
@@ -526,10 +606,14 @@ class ACIModule(object):
             return
 
         # Extract JSON API output
-        self.imdata = jsondata.get("imdata")
-        if self.imdata is None:
-            self.imdata = dict()
-        self.totalCount = int(jsondata.get("totalCount"))
+        if isinstance(jsondata, list):
+            self.imdata = jsondata
+            self.totalCount = len(jsondata)
+        else:
+            self.imdata = jsondata.get("imdata", {})
+            total_count = jsondata.get("totalCount")
+            if total_count is not None:
+                self.totalCount = int(total_count)
 
         # Handle possible APIC error information
         self.response_error()
@@ -551,7 +635,7 @@ class ACIModule(object):
         self.imdata = xmldata.get("imdata", {}).get("children")
         if self.imdata is None:
             self.imdata = dict()
-        self.totalCount = int(xmldata.get("imdata", {}).get("attributes", {}).get("totalCount"))
+        self.totalCount = int(xmldata.get("imdata", {}).get("attributes", {}).get("totalCount", -1))
 
         # Handle possible APIC error information
         self.response_error()
@@ -774,8 +858,10 @@ class ACIModule(object):
         subclass_3=None,
         subclass_4=None,
         subclass_5=None,
+        subclass_6=None,
         child_classes=None,
         config_only=True,
+        rsp_subtree="full",
     ):
         """
         This method is used to retrieve the appropriate URL path and filter_string to make the request to the APIC.
@@ -791,6 +877,7 @@ class ACIModule(object):
         :type subclass_3: dict
         :type subclass_4: dict
         :type subclass_5: dict
+        :type subclass_6: dict
         :type child_classes: list
         :return: The path and filter_string needed to build the full URL.
         """
@@ -801,7 +888,9 @@ class ACIModule(object):
         else:
             self.child_classes = set(child_classes)
 
-        if subclass_5 is not None:
+        if subclass_6 is not None:
+            self._construct_url_7(root_class, subclass_1, subclass_2, subclass_3, subclass_4, subclass_5, subclass_6, config_only)
+        elif subclass_5 is not None:
             self._construct_url_6(root_class, subclass_1, subclass_2, subclass_3, subclass_4, subclass_5, config_only)
         elif subclass_4 is not None:
             self._construct_url_5(root_class, subclass_1, subclass_2, subclass_3, subclass_4, config_only)
@@ -823,10 +912,12 @@ class ACIModule(object):
             # Append child_classes to filter_string if filter string is empty
             self.update_qs(
                 {
-                    "rsp-subtree": "full",
+                    "rsp-subtree": rsp_subtree,
                     "rsp-subtree-class": ",".join(sorted(self.child_classes)),
                 }
             )
+        elif rsp_subtree == "children":
+            self.update_qs({"rsp-subtree": rsp_subtree})
 
     def _construct_url_1(self, obj, config_only=True):
         """
@@ -1072,7 +1163,7 @@ class ACIModule(object):
 
     def _construct_url_6(self, root, quad, ter, sec, parent, obj, config_only=True):
         """
-        This method is used by construct_url when the object is the fourth-level class.
+        This method is used by construct_url when the object is the fifth-level class.
         """
         root_rn = root.get("aci_rn")
         root_obj = root.get("module_object")
@@ -1140,6 +1231,85 @@ class ACIModule(object):
             # Query for a specific object of the module's class
             self.path = "api/mo/uni/{0}/{1}/{2}/{3}/{4}/{5}.json".format(root_rn, quad_rn, ter_rn, sec_rn, parent_rn, obj_rn)
 
+    def _construct_url_7(self, root, quin, quad, ter, sec, parent, obj, config_only=True):
+        """
+        This method is used by construct_url when the object is the sixth-level class.
+        """
+        root_rn = root.get("aci_rn")
+        root_obj = root.get("module_object")
+        quin_rn = quin.get("aci_rn")
+        quin_obj = quin.get("module_object")
+        quad_rn = quad.get("aci_rn")
+        quad_obj = quad.get("module_object")
+        ter_rn = ter.get("aci_rn")
+        ter_obj = ter.get("module_object")
+        sec_rn = sec.get("aci_rn")
+        sec_obj = sec.get("module_object")
+        parent_rn = parent.get("aci_rn")
+        parent_obj = parent.get("module_object")
+        obj_class = obj.get("aci_class")
+        obj_rn = obj.get("aci_rn")
+        obj_filter = obj.get("target_filter")
+        mo = obj.get("module_object")
+
+        if self.child_classes is None:
+            self.child_classes = [obj_class]
+
+        if self.module.params.get("state") in ("absent", "present"):
+            # State is absent or present
+            self.path = "api/mo/uni/{0}/{1}/{2}/{3}/{4}/{5}/{6}.json".format(root_rn, quin_rn, quad_rn, ter_rn, sec_rn, parent_rn, obj_rn)
+            if config_only:
+                self.update_qs({"rsp-prop-include": "config-only"})
+            self.obj_filter = obj_filter
+        # TODO: Add all missing cases
+        elif root_obj is None:
+            self.child_classes.add(obj_class)
+            self.path = "api/class/{0}.json".format(obj_class)
+            self.update_qs({"query-target-filter": self.build_filter(obj_class, obj_filter)})
+        elif quin_obj is None:
+            self.child_classes.add(obj_class)
+            self.path = "api/mo/uni/{0}.json".format(root_rn)
+            # NOTE: No need to select by root_filter
+            # self.update_qs({'query-target-filter': self.build_filter(root_class, root_filter)})
+            # TODO: Filter by quin_filter, parent and obj_filter
+            self.update_qs({"rsp-subtree-filter": self.build_filter(obj_class, obj_filter)})
+        elif quad_obj is None:
+            self.child_classes.add(obj_class)
+            self.path = "api/mo/uni/{0}/{1}.json".format(root_rn, quin_rn)
+            # NOTE: No need to select by root_filter
+            # self.update_qs({'query-target-filter': self.build_filter(root_class, root_filter)})
+            # TODO: Filter by quin_filter, parent and obj_filter
+            self.update_qs({"rsp-subtree-filter": self.build_filter(obj_class, obj_filter)})
+        elif ter_obj is None:
+            self.child_classes.add(obj_class)
+            self.path = "api/mo/uni/{0}/{1}/{2}.json".format(root_rn, quin_rn, quad_rn)
+            # NOTE: No need to select by quad_filter
+            # self.update_qs({'query-target-filter': self.build_filter(quin_class, quin_filter)})
+            # TODO: Filter by ter_filter, parent and obj_filter
+            self.update_qs({"rsp-subtree-filter": self.build_filter(obj_class, obj_filter)})
+        elif sec_obj is None:
+            self.child_classes.add(obj_class)
+            self.path = "api/mo/uni/{0}/{1}/{2}/{3}.json".format(root_rn, quin_rn, quad_rn, ter_rn)
+            # NOTE: No need to select by ter_filter
+            # self.update_qs({'query-target-filter': self.build_filter(ter_class, ter_filter)})
+            # TODO: Filter by sec_filter, parent and obj_filter
+            self.update_qs({"rsp-subtree-filter": self.build_filter(obj_class, obj_filter)})
+        elif parent_obj is None:
+            self.child_classes.add(obj_class)
+            self.path = "api/mo/uni/{0}/{1}/{2}/{3}/{4}.json".format(root_rn, quin_rn, quad_rn, ter_rn, sec_rn)
+            # NOTE: No need to select by sec_filter
+            # self.update_qs({'query-target-filter': self.build_filter(sec_class, sec_filter)})
+            # TODO: Filter by parent_filter and obj_filter
+            self.update_qs({"rsp-subtree-filter": self.build_filter(obj_class, obj_filter)})
+        elif mo is None:
+            self.child_classes.add(obj_class)
+            self.path = "api/mo/uni/{0}/{1}/{2}/{3}/{4}/{5}.json".format(root_rn, quin_rn, quad_rn, ter_rn, sec_rn, parent_rn)
+            # NOTE: No need to select by parent_filter
+            # self.update_qs({'query-target-filter': self.build_filter(parent_class, parent_filter)})
+        else:
+            # Query for a specific object of the module's class
+            self.path = "api/mo/uni/{0}/{1}/{2}/{3}/{4}/{5}/{6}.json".format(root_rn, quin_rn, quad_rn, ter_rn, sec_rn, parent_rn, obj_rn)
+
     def delete_config(self):
         """
         This method is used to handle the logic when the modules state is equal to absent. The method only pushes a change if
@@ -1147,7 +1317,7 @@ class ACIModule(object):
         """
         self.proposed = dict()
 
-        if not self.existing:
+        if not self.existing and not self.suppress_previous:
             return
         elif not self.module.check_mode:
             # Sign and encode request as to APIC's wishes
@@ -1156,7 +1326,7 @@ class ACIModule(object):
             self.result["changed"] = True
             self.method = "DELETE"
 
-    def get_diff(self, aci_class):
+    def get_diff(self, aci_class, required_properties=None):
         """
         This method is used to get the difference between the proposed and existing configurations. Each module
         should call the get_existing method before this method, and add the proposed config to the module results
@@ -1178,6 +1348,8 @@ class ACIModule(object):
             # add name back to config only if the configs do not match
             if config:
                 # TODO: If URLs are built with the object's name, then we should be able to leave off adding the name back
+                if required_properties and isinstance(required_properties, dict):
+                    config.update(required_properties)
                 config = {aci_class: {"attributes": config}}
 
             # check for updates to child configs and update new config dictionary
@@ -1272,10 +1444,30 @@ class ACIModule(object):
         that this method can be used to supply the existing configuration when using the get_diff method. The response, status,
         and existing configuration will be added to the self.result dictionary.
         """
-        uri = self.url + self.filter_string
+        if self.suppress_previous:
+            self.existing = []
+            return
 
+        uri = self.url + self.filter_string
         self.api_call("GET", uri, data=None, return_response=False)
 
+    def __get_existing_validation(self, changed):
+        """
+        This method is used to get the existing object(s) state after a config change has been completed.
+        It will not get the object(s) state if there is no change or suppress_verification is enabled.
+        When suppress_verification is enabled, the existing will be set to proposed if there was a change or suppress_previous is enabled.
+        """
+        if self.suppress_verification:
+            if changed or self.suppress_previous:
+                self.result["current_verified"] = False
+                self.existing = [self.proposed] if self.proposed != {} else []
+            else:
+                # existing already equals the previous
+                self.result["current_verified"] = True
+        elif changed:
+            uri = self.url + self.filter_string
+            self.api_call("GET", uri, data=None, return_response=False)
+
     @staticmethod
     def get_nested_config(proposed_child, existing_children):
         """
@@ -1364,23 +1556,30 @@ class ACIModule(object):
 
         # add child objects to proposed
         if child_configs:
-            children = []
-            for child in child_configs:
-                child_copy = deepcopy(child)
-                has_value = False
-                for root_key in child_copy.keys():
-                    for final_keys, values in child_copy[root_key]["attributes"].items():
-                        if values is None:
-                            child[root_key]["attributes"].pop(final_keys)
-                        else:
-                            child[root_key]["attributes"][final_keys] = str(values)
-                            has_value = True
-                if has_value:
-                    children.append(child)
+            children = self.handle_child_configs(child_configs)
 
             if children:
                 self.proposed[aci_class].update(dict(children=children))
 
+    def handle_child_configs(self, child_configs):
+        children = []
+        for child in child_configs:
+            child_copy = deepcopy(child)
+            has_value = False
+            for class_name in child_copy.keys():
+                for attribute, value in child_copy[class_name]["attributes"].items():
+                    if value is None:
+                        child[class_name]["attributes"].pop(attribute)
+                    else:
+                        child[class_name]["attributes"][attribute] = str(value)
+                        has_value = True
+                if child_copy[class_name].get("children") is not None:
+                    has_value = True
+                    child[class_name]["children"] = self.handle_child_configs(child_copy[class_name]["children"])
+            if has_value:
+                children.append(child)
+        return children
+
     def post_config(self, parent_class=None):
         """
         This method is used to handle the logic when the modules state is equal to present. The method only pushes a change if
@@ -1433,7 +1632,7 @@ class ACIModule(object):
         if "state" in self.params:
             self.original = self.existing
             if self.params.get("state") in ("absent", "present"):
-                self.get_existing()
+                self.__get_existing_validation(self.result["changed"])
 
             # if self.module._diff and self.original != self.existing:
             #     self.result['diff'] = dict(
@@ -1528,6 +1727,7 @@ class ACIModule(object):
         if self.connection is not None:
             self.connection.set_params(self.params)
             info = self.connection.send_request(method, self.parsed_url_path(url), data)
+            self.url = "{protocol}://{host}/{path}".format_map(integrate_url(info.get("url"), self.path))
             self.error = info.get("error")
             self.httpapi_logs.extend(self.connection.pop_messages())
         else:
@@ -1539,8 +1739,8 @@ class ACIModule(object):
                 data=data,
                 headers=self.headers,
                 method=method,
-                timeout=self.params.get("timeout", 30),
-                use_proxy=self.params.get("use_proxy", True),
+                timeout=30 if self.params.get("timeout") is None else self.params.get("timeout"),
+                use_proxy=True if self.params.get("use_proxy") is None else self.params.get("use_proxy"),
             )
 
         self.response = info.get("msg")
