@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
-
 DOCUMENTATION = r"""
 ---
 module: buildings_planned_access_points_info
 short_description: Information module for Buildings Planned Access Points Info
 description:
-- This module represents an alias of the module buildings_planned_access_points_v1_info
+  - This module represents an alias of the module buildings_planned_access_points_v1_info
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,39 +18,38 @@ options:
     type: dict
   buildingId:
     description:
-    - BuildingId path parameter. The instance UUID of the building hierarchy element.
+      - BuildingId path parameter. The instance UUID of the building hierarchy element.
     type: str
   limit:
     description:
-    - Limit query parameter. The number of records to show for this page;The minimum is 1, and the maximum is 500.
+      - Limit query parameter. The number of records to show for this page;The minimum
+        is 1, and the maximum is 500.
     type: float
   offset:
     description:
-    - >
-      Offset query parameter. The page offset for the response. E.g. If limit=100, offset=0 will return first 100
-      records, offset=1 will return next 100 records, etc.
+      - >
+        Offset query parameter. The page offset for the response. E.g. If limit=100,
+        offset=0 will return first 100
+        records, offset=1 will return next 100 records, etc.
     type: float
   radios:
     description:
-    - Radios query parameter. Whether to include the planned radio details of the planned access points.
+      - Radios query parameter. Whether to include the planned radio details of the
+        planned access points.
     type: bool
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices GetPlannedAccessPointsForBuildingV1
-  description: Complete reference of the GetPlannedAccessPointsForBuildingV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-planned-access-points-for-building
+  - name: Cisco DNA Center documentation for Devices GetPlannedAccessPointsForBuildingV1
+    description: Complete reference of the GetPlannedAccessPointsForBuildingV1 API.
+    link:
+      https://developer.cisco.com/docs/dna-center/#!get-planned-access-points-for-building
 notes:
-  - SDK Method used are
-    devices.Devices.get_planned_access_points_for_building_v1,
-
-  - Paths used are
-    get /dna/intent/api/v1/buildings/{buildingId}/planned-access-points,
+  - SDK Method used are devices.Devices.get_planned_access_points_for_building_v1,
+  - Paths used are get /dna/intent/api/v1/buildings/{buildingId}/planned-access-points,
   - It should be noted that this module is an alias of buildings_planned_access_points_v1_info
-
 """
-
 EXAMPLES = r"""
 - name: Get all Buildings Planned Access Points Info
   cisco.dnac.buildings_planned_access_points_info:
@@ -67,10 +63,9 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     limit: 0
     offset: 0
-    radios: True
+    radios: true
     buildingId: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
