@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: configuration_template_export_project
 short_description: Resource module for Configuration Template Export Project
 description:
-- Manage operation create of the resource Configuration Template Export Project.
-- Exports the projects for given projectNames.
+  - This module represents an alias of the module configuration_template_export_project_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -21,21 +18,18 @@ options:
     elements: dict
     type: list
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Configuration Templates ExportsTheProjectsForAGivenCriteria
-  description: Complete reference of the ExportsTheProjectsForAGivenCriteria API.
-  link: https://developer.cisco.com/docs/dna-center/#!exports-the-projects-for-a-given-criteria
+  - name: Cisco DNA Center documentation for Configuration Templates ExportsTheProjectsForAGivenCriteriaV1
+    description: Complete reference of the ExportsTheProjectsForAGivenCriteriaV1 API.
+    link:
+      https://developer.cisco.com/docs/dna-center/#!exports-the-projects-for-a-given-criteria
 notes:
-  - SDK Method used are
-    configuration_templates.ConfigurationTemplates.export_projects,
-
-  - Paths used are
-    post /dna/intent/api/v1/template-programmer/project/name/exportprojects,
-
+  - SDK Method used are configuration_templates.ConfigurationTemplates.export_projects,
+  - Paths used are post /dna/intent/api/v1/template-programmer/project/name/exportprojects,
+  - It should be noted that this module is an alias of configuration_template_export_project_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.configuration_template_export_project:
@@ -47,8 +41,7 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     payload:
-    - {}
-
+      - {}
 """
 RETURN = r"""
 dnac_response:
