@@ -1,43 +1,33 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: file_import
 short_description: Resource module for File Import
 description:
-- Manage operation create of the resource File Import.
-- Uploads a new file within a specific nameSpace.
+  - This module represents an alias of the module file_import_v1
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
-  filePath:
-    description: File absolute path.
-    type: str
   nameSpace:
     description: NameSpace path parameter.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for File UploadFile
-  description: Complete reference of the UploadFile API.
-  link: https://developer.cisco.com/docs/dna-center/#!upload-file
+  - name: Cisco DNA Center documentation for File UploadFileV1
+    description: Complete reference of the UploadFileV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!upload-file
 notes:
-  - SDK Method used are
-    file.File.upload_file,
-
-  - Paths used are
-    post /dna/intent/api/v1/file/{nameSpace},
-
+  - SDK Method used are file.File.upload_file_v1,
+  - Paths used are post /dna/intent/api/v1/file/{nameSpace},
+  - It should be noted that this module is an alias of file_import_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.file_import:
@@ -48,9 +38,7 @@ EXAMPLES = r"""
     dnac_port: "{{dnac_port}}"
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
-    filePath: /tmp/uploads/Test-242.bin
     nameSpace: string
-
 """
 RETURN = r"""
 dnac_response:
