@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
-
 DOCUMENTATION = r"""
 ---
 module: lan_automation_delete
 short_description: Resource module for Lan Automation Delete
 description:
-- This module represents an alias of the module lan_automation_delete_v1
+  - This module represents an alias of the module lan_automation_delete_v1
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -20,22 +17,17 @@ options:
     description: Id path parameter. LAN Automation id can be obtained from /dna/intent/api/v1/lan-automation/status.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for LAN Automation LANAutomationStopV1
-  description: Complete reference of the LANAutomationStopV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-stop
+  - name: Cisco DNA Center documentation for LAN Automation LANAutomationStopV1
+    description: Complete reference of the LANAutomationStopV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-stop
 notes:
-  - SDK Method used are
-    lan_automation.LanAutomation.lan_automation_stop_v1,
-
-  - Paths used are
-    delete /dna/intent/api/v1/lan-automation/{id},
+  - SDK Method used are lan_automation.LanAutomation.lan_automation_stop_v1,
+  - Paths used are delete /dna/intent/api/v1/lan-automation/{id},
   - It should be noted that this module is an alias of lan_automation_delete_v1
-
 """
-
 EXAMPLES = r"""
 - name: Delete by id
   cisco.dnac.lan_automation_delete:
@@ -47,7 +39,6 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     id: string
-
 """
 RETURN = r"""
 dnac_response:
