@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: network_device_polling_interval_info
-short_description: Information module for Network Device Polling Interval
+short_description: Information module for Network Device Polling Interval Info
 description:
-- Get all Network Device Polling Interval.
-- Returns polling interval by device id.
+  - This module represents an alias of the module network_device_polling_interval_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,26 +18,22 @@ options:
     type: dict
   id:
     description:
-    - Id path parameter. Device ID.
+      - Id path parameter. Device ID.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices GetPollingIntervalById
-  description: Complete reference of the GetPollingIntervalById API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-polling-interval-by-id
+  - name: Cisco DNA Center documentation for Devices GetPollingIntervalByIdV1
+    description: Complete reference of the GetPollingIntervalByIdV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-polling-interval-by-id
 notes:
-  - SDK Method used are
-    devices.Devices.get_polling_interval_by_id,
-
-  - Paths used are
-    get /dna/intent/api/v1/network-device/{id}/collection-schedule,
-
+  - SDK Method used are devices.Devices.get_polling_interval_by_id_v1,
+  - Paths used are get /dna/intent/api/v1/network-device/{id}/collection-schedule,
+  - It should be noted that this module is an alias of network_device_polling_interval_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Network Device Polling Interval
+- name: Get all Network Device Polling Interval Info
   cisco.dnac.network_device_polling_interval_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -52,7 +45,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     id: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
