@@ -1,21 +1,22 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: network_devices_trend_analytics_v1
 short_description: Resource module for Network Devices Trend Analytics V1
 description:
-- Manage operation create of the resource Network Devices Trend Analytics V1.
-- >
-   Gets the Trend analytics Network device data for the given time range. The data will be grouped based on the given
-   trend time Interval. The required property for this API is `trendInterval`. For detailed information about the
-   usage of the API, please refer to the Open API specification document - https //github.com/cisco-en-
-   programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
-   AssuranceNetworkDevices-2.0.1-resolved.yaml.
+  - Manage operation create of the resource Network Devices Trend Analytics V1.
+  - >
+    Gets the Trend analytics Network device data for the given time range. The data
+    will be grouped based on the given
+    trend time Interval. The required property for this API is `trendInterval`. For
+    detailed information about the
+    usage of the API, please refer to the Open API specification document - https
+    //github.com/cisco-en-
+    programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
+    AssuranceNetworkDevices-2.0.1-resolved.yaml.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -70,21 +71,16 @@ options:
     description: Trend Interval.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices GetsTheTrendAnalyticsDataV1
-  description: Complete reference of the GetsTheTrendAnalyticsDataV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!gets-the-trend-analytics-data
+  - name: Cisco DNA Center documentation for Devices GetsTheTrendAnalyticsDataV1
+    description: Complete reference of the GetsTheTrendAnalyticsDataV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!gets-the-trend-analytics-data
 notes:
-  - SDK Method used are
-    devices.Devices.gets_the_trend_analytics_data_v1,
-
-  - Paths used are
-    post /dna/data/api/v1/networkDevices/trendAnalytics,
-
+  - SDK Method used are devices.Devices.gets_the_trend_analytics_data_v1,
+  - Paths used are post /dna/data/api/v1/networkDevices/trendAnalytics,
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.network_devices_trend_analytics_v1:
@@ -96,23 +92,22 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     aggregateAttributes:
-    - {}
+      - {}
     attributes:
-    - string
+      - string
     endTime: 0
     filters:
-    - key: string
-      operator: string
-      value: string
+      - key: string
+        operator: string
+        value: string
     groupBy:
-    - {}
+      - {}
     page:
       limit: 0
       offset: 0
       timestampOrder: string
     startTime: 0
     trendInterval: string
-
 """
 RETURN = r"""
 dnac_response:
