@@ -1,18 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: reserve_ip_subpool
 short_description: Resource module for Reserve Ip Subpool
 description:
-- Manage operations create, update and delete of the resource Reserve Ip Subpool.
-- API to reserve an ip subpool from the global pool.
-- API to delete the reserved ip subpool.
-- API to update ip subpool from the global pool.
+  - This module represents an alias of the module reserve_ip_subpool_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -22,11 +17,11 @@ options:
     description: Id path parameter. Id of reserve ip subpool to be deleted.
     type: str
   ipv4DhcpServers:
-    description: IPv4 input for dhcp server ip example 1.1.1.1.
+    description: IPv4 input for dhcp server ip example "1.1.1.1".
     elements: str
     type: list
   ipv4DnsServers:
-    description: IPv4 input for dns server ip example 4.4.4.4.
+    description: IPv4 input for dns server ip example "4.4.4.4".
     elements: str
     type: list
   ipv4GateWay:
@@ -44,21 +39,22 @@ options:
     description: The ipv4 prefix length is required when ipv4prefix value is true.
     type: int
   ipv4Subnet:
-    description: IPv4 Subnet address, example 175.175.0.0.
+    description: IPv4 Subnet address, example 175.175.0.0. Either ipv4Subnet or ipv4TotalHost
+      needs to be passed if creating IPv4 subpool.
     type: str
   ipv4TotalHost:
     description: IPv4 total host is required when ipv4prefix value is false.
     type: int
   ipv6AddressSpace:
-    description: If the value is false only ipv4 input are required, otherwise both
-      ipv6 and ipv4 are required.
+    description: If the value is omitted or false only ipv4 input are required, otherwise
+      both ipv6 and ipv4 are required.
     type: bool
   ipv6DhcpServers:
-    description: IPv6 format dhcp server as input example 2001 db8 1234.
+    description: IPv6 format dhcp server as input example "2001 db8 1234".
     elements: str
     type: list
   ipv6DnsServers:
-    description: IPv6 format dns server input example 2001 db8 1234.
+    description: IPv6 format dns server input example "2001 db8 1234".
     elements: str
     type: list
   ipv6GateWay:
@@ -76,7 +72,8 @@ options:
     description: IPv6 prefix length is required when the ipv6prefix value is true.
     type: int
   ipv6Subnet:
-    description: IPv6 Subnet address, example 2001 db8 85a3 0 100.
+    description: IPv6 Subnet address, example 2001 db8 85a3 0 100. Either ipv6Subnet
+      or ipv6TotalHost needs to be passed if creating IPv6 subpool.
     type: str
   ipv6TotalHost:
     description: IPv6 total host is required when ipv6prefix value is false.
@@ -94,31 +91,25 @@ options:
     description: Type of the reserve ip sub pool.
     type: str
 requirements:
-- dnacentersdk >= 2.5.5
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Network Settings ReserveIPSubpool
-  description: Complete reference of the ReserveIPSubpool API.
-  link: https://developer.cisco.com/docs/dna-center/#!reserve-ip-subpool
-- name: Cisco DNA Center documentation for Network Settings ReleaseReserveIPSubpool
-  description: Complete reference of the ReleaseReserveIPSubpool API.
-  link: https://developer.cisco.com/docs/dna-center/#!release-reserve-ip-subpool
-- name: Cisco DNA Center documentation for Network Settings UpdateReserveIPSubpool
-  description: Complete reference of the UpdateReserveIPSubpool API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-reserve-ip-subpool
+  - name: Cisco DNA Center documentation for Network Settings ReserveIPSubpoolV1
+    description: Complete reference of the ReserveIPSubpoolV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!reserve-ip-subpool
+  - name: Cisco DNA Center documentation for Network Settings ReleaseReserveIPSubpoolV1
+    description: Complete reference of the ReleaseReserveIPSubpoolV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!release-reserve-ip-subpool
+  - name: Cisco DNA Center documentation for Network Settings UpdateReserveIPSubpoolV1
+    description: Complete reference of the UpdateReserveIPSubpoolV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!update-reserve-ip-subpool
 notes:
-  - SDK Method used are
-    network_settings.NetworkSettings.release_reserve_ip_subpool,
-    network_settings.NetworkSettings.reserve_ip_subpool,
-    network_settings.NetworkSettings.update_reserve_ip_subpool,
-
-  - Paths used are
-    post /dna/intent/api/v1/reserve-ip-subpool/{siteId},
-    delete /dna/intent/api/v1/reserve-ip-subpool/{id},
+  - SDK Method used are network_settings.NetworkSettings.release_reserve_ip_subpool_v1,
+    network_settings.NetworkSettings.reserve_ip_subpool_v1, network_settings.NetworkSettings.update_reserve_ip_subpool_v1,
+  - Paths used are post /dna/intent/api/v1/reserve-ip-subpool/{siteId}, delete /dna/intent/api/v1/reserve-ip-subpool/{id},
     put /dna/intent/api/v1/reserve-ip-subpool/{siteId},
-
+  - It should be noted that this module is an alias of reserve_ip_subpool_v1
 """
-
 EXAMPLES = r"""
 - name: Delete by id
   cisco.dnac.reserve_ip_subpool:
@@ -131,7 +122,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     id: string
-
 - name: Create
   cisco.dnac.reserve_ip_subpool:
     dnac_host: "{{dnac_host}}"
@@ -143,9 +133,9 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: present
     ipv4DhcpServers:
-    - string
+      - string
     ipv4DnsServers:
-    - string
+      - string
     ipv4GateWay: string
     ipv4GlobalPool: string
     ipv4Prefix: true
@@ -154,9 +144,9 @@ EXAMPLES = r"""
     ipv4TotalHost: 0
     ipv6AddressSpace: true
     ipv6DhcpServers:
-    - string
+      - string
     ipv6DnsServers:
-    - string
+      - string
     ipv6GateWay: string
     ipv6GlobalPool: string
     ipv6Prefix: true
@@ -167,7 +157,6 @@ EXAMPLES = r"""
     siteId: string
     slaacSupport: true
     type: string
-
 - name: Update by id
   cisco.dnac.reserve_ip_subpool:
     dnac_host: "{{dnac_host}}"
@@ -180,15 +169,15 @@ EXAMPLES = r"""
     state: present
     id: string
     ipv4DhcpServers:
-    - string
+      - string
     ipv4DnsServers:
-    - string
+      - string
     ipv4GateWay: string
     ipv6AddressSpace: true
     ipv6DhcpServers:
-    - string
+      - string
     ipv6DnsServers:
-    - string
+      - string
     ipv6GateWay: string
     ipv6GlobalPool: string
     ipv6Prefix: true
@@ -198,9 +187,7 @@ EXAMPLES = r"""
     name: string
     siteId: string
     slaacSupport: true
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
