@@ -1,16 +1,14 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: sda_virtual_network_v2_info
 short_description: Information module for Sda Virtual Network V2
 description:
-- Get all Sda Virtual Network V2.
-- Get virtual network with scalable groups.
+  - Get all Sda Virtual Network V2.
+  - Get virtual network with scalable groups.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,24 +19,20 @@ options:
     type: dict
   virtualNetworkName:
     description:
-    - VirtualNetworkName query parameter.
+      - VirtualNetworkName query parameter.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for SDA GetVirtualNetworkWithScalableGroupsV1
-  description: Complete reference of the GetVirtualNetworkWithScalableGroupsV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-virtual-network-with-scalable-groups
+  - name: Cisco DNA Center documentation for SDA GetVirtualNetworkWithScalableGroupsV1
+    description: Complete reference of the GetVirtualNetworkWithScalableGroupsV1 API.
+    link:
+      https://developer.cisco.com/docs/dna-center/#!get-virtual-network-with-scalable-groups
 notes:
-  - SDK Method used are
-    sda.Sda.get_virtual_network_with_scalable_groups_v1,
-
-  - Paths used are
-    get /dna/intent/api/v1/virtual-network,
-
+  - SDK Method used are sda.Sda.get_virtual_network_with_scalable_groups_v1,
+  - Paths used are get /dna/intent/api/v1/virtual-network,
 """
-
 EXAMPLES = r"""
 - name: Get all Sda Virtual Network V2
   cisco.dnac.sda_virtual_network_v2_info:
@@ -52,7 +46,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     virtualNetworkName: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
