@@ -1,16 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
-
 DOCUMENTATION = r"""
 ---
 module: snmpv2_write_community_credential
 short_description: Resource module for Snmpv2 Write Community Credential
 description:
-- This module represents an alias of the module snmpv2_write_community_credential_v1
+  - This module represents an alias of the module snmpv2_write_community_credential_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -32,27 +29,21 @@ options:
     description: SNMP write community. NO!$DATA!$ for no value change.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Discovery CreateSNMPWriteCommunityV1
-  description: Complete reference of the CreateSNMPWriteCommunityV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!create-snmp-write-community
-- name: Cisco DNA Center documentation for Discovery UpdateSNMPWriteCommunityV1
-  description: Complete reference of the UpdateSNMPWriteCommunityV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!update-snmp-write-community
+  - name: Cisco DNA Center documentation for Discovery CreateSNMPWriteCommunityV1
+    description: Complete reference of the CreateSNMPWriteCommunityV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!create-snmp-write-community
+  - name: Cisco DNA Center documentation for Discovery UpdateSNMPWriteCommunityV1
+    description: Complete reference of the UpdateSNMPWriteCommunityV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!update-snmp-write-community
 notes:
-  - SDK Method used are
-    discovery.Discovery.create_snmp_write_community_v1,
-    discovery.Discovery.update_snmp_write_community_v1,
-
-  - Paths used are
-    post /dna/intent/api/v1/global-credential/snmpv2-write-community,
+  - SDK Method used are discovery.Discovery.create_snmp_write_community_v1, discovery.Discovery.update_snmp_write_community_v1,
+  - Paths used are post /dna/intent/api/v1/global-credential/snmpv2-write-community,
     put /dna/intent/api/v1/global-credential/snmpv2-write-community,
   - It should be noted that this module is an alias of snmpv2_write_community_credential_v1
-
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.snmpv2_write_community_credential:
@@ -68,7 +59,6 @@ EXAMPLES = r"""
     credentialType: string
     description: string
     writeCommunity: string
-
 - name: Update all
   cisco.dnac.snmpv2_write_community_credential:
     dnac_host: "{{dnac_host}}"
@@ -84,7 +74,6 @@ EXAMPLES = r"""
     description: string
     instanceUuid: string
     writeCommunity: string
-
 """
 RETURN = r"""
 dnac_response:
