@@ -26,8 +26,7 @@ from ansible_collections.cisco.ise.plugins.plugin_utils.ise import (
 # Get common arguements specification
 argument_spec = ise_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-))
+argument_spec.update(dict())
 
 required_if = []
 required_one_of = []
@@ -38,7 +37,9 @@ required_together = []
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = True
@@ -63,8 +64,7 @@ class ActionModule(ActionBase):
             raise AnsibleActionFail(errors)
 
     def get_object(self, params):
-        new_object = dict(
-        )
+        new_object = dict()
         return new_object
 
     def run(self, tmp=None, task_vars=None):
@@ -82,8 +82,8 @@ class ActionModule(ActionBase):
         if not name and not id:
             response = ise.exec(
                 family="licensing",
-                function='get_tier_state_info',
-                params=self.get_object(self._task.args)
+                function="get_tier_state_info",
+                params=self.get_object(self._task.args),
             ).response
             self._result.update(dict(ise_response=response))
             self._result.update(ise.exit_json())
