@@ -9,8 +9,7 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: crypto_info
 author: "Felix Fontein (@felixfontein)"
 short_description: Retrieve cryptographic capabilities
@@ -22,10 +21,11 @@ description:
 extends_documentation_fragment:
   - community.crypto.attributes
   - community.crypto.attributes.info_module
+  - community.crypto.attributes.idempotent_not_modify_state
 options: {}
-'''
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 - name: Retrieve information
   community.crypto.crypto_info:
     account_key_src: /etc/pki/cert/private/account.key
@@ -34,9 +34,9 @@ EXAMPLES = r'''
 - name: Show retrieved information
   ansible.builtin.debug:
     var: crypto_information
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 python_cryptography_installed:
   description: Whether the L(Python cryptography library, https://cryptography.io/) is installed.
   returned: always
@@ -151,7 +151,7 @@ openssl:
       description: The complete output of C(openssl version).
       type: str
       sample: 'OpenSSL 1.1.1m  14 Dec 2021\n'
-'''
+"""
 
 import traceback
 
@@ -177,8 +177,16 @@ from ansible_collections.community.crypto.plugins.module_utils.crypto.basic impo
 try:
     import cryptography
     from cryptography.exceptions import UnsupportedAlgorithm
+
+    try:
+        # While UnsupportedAlgorithm got added in cryptography 0.1, InternalError
+        # only got added in 0.2, so let's guard the import
+        from cryptography.exceptions import InternalError as CryptographyInternalError
+    except ImportError:
+        CryptographyInternalError = Exception
 except ImportError:
     UnsupportedAlgorithm = Exception
+    CryptographyInternalError = Exception
     CRYPTOGRAPHY_VERSION = None
     CRYPTOGRAPHY_IMP_ERR = traceback.format_exc()
 else:
@@ -274,6 +282,11 @@ def add_crypto_information(module):
                     curves.append(curve_name)
                 except UnsupportedAlgorithm:
                     pass
+                except CryptographyInternalError:  # pylint: disable=duplicate-except,bad-except-order
+                    # On Fedora 41, some curves result in InternalError. This is probably because
+                    # Fedora's cryptography is linked against the system libssl, which has the
+                    # curves removed.
+                    pass
 
     info = {
         'version': CRYPTOGRAPHY_VERSION,
