@@ -3,8 +3,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = '''
     author: Unknown (!UNKNOWN)
@@ -20,6 +19,7 @@ DOCUMENTATION = '''
     options:
         plugin:
             description: token that ensures this is a source file for the 'nmap' plugin.
+            type: string
             required: true
             choices: ['nmap', 'community.general.nmap']
         sudo:
@@ -29,6 +29,7 @@ DOCUMENTATION = '''
             type: boolean
         address:
             description: Network IP or range of IPs to scan, you can use a simple range (10.2.2.15-25) or CIDR notation.
+            type: string
             required: true
             env:
                 - name: ANSIBLE_NMAP_ADDRESS
@@ -85,28 +86,35 @@ DOCUMENTATION = '''
             type: boolean
             default: false
             version_added: 6.1.0
+        dns_servers:
+            description: Specify which DNS servers to use for name resolution.
+            type: list
+            elements: string
+            version_added: 10.5.0
         use_arp_ping:
             description: Whether to always (V(true)) use the quick ARP ping or (V(false)) a slower but more reliable method.
             type: boolean
             default: true
             version_added: 7.4.0
     notes:
-        - At least one of ipv4 or ipv6 is required to be True, both can be True, but they cannot both be False.
+        - At least one of O(ipv4) or O(ipv6) is required to be V(true); both can be V(true), but they cannot both be V(false).
         - 'TODO: add OS fingerprinting'
 '''
 EXAMPLES = '''
+---
 # inventory.config file in YAML format
 plugin: community.general.nmap
 strict: false
 address: 192.168.0.0/24
 
-
+---
 # a sudo nmap scan to fully use nmap scan power.
 plugin: community.general.nmap
 sudo: true
 strict: false
 address: 192.168.0.0/24
 
+---
 # an nmap scan specifying ports and classifying results to an inventory group
 plugin: community.general.nmap
 address: 192.168.0.0/24
@@ -127,6 +135,8 @@ from ansible.module_utils.common.text.converters import to_native, to_text
 from ansible.plugins.inventory import BaseInventoryPlugin, Constructable, Cacheable
 from ansible.module_utils.common.process import get_bin_path
 
+from ansible_collections.community.general.plugins.plugin_utils.unsafe import make_unsafe
+
 
 class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
 
@@ -143,6 +153,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         strict = self.get_option('strict')
 
         for host in hosts:
+            host = make_unsafe(host)
             hostname = host['name']
             self.inventory.add_host(hostname)
             for var, value in host.items():
@@ -173,7 +184,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         try:
             self._nmap = get_bin_path('nmap')
         except ValueError as e:
-            raise AnsibleParserError('nmap inventory plugin requires the nmap cli tool to work: {0}'.format(to_native(e)))
+            raise AnsibleParserError(f'nmap inventory plugin requires the nmap cli tool to work: {e}')
 
         super(InventoryModule, self).parse(inventory, loader, path, cache=cache)
 
@@ -201,49 +212,53 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             # setup command
             cmd = [self._nmap]
 
-            if self.get_option['sudo']:
+            if self.get_option('sudo'):
                 cmd.insert(0, 'sudo')
 
-            if self.get_option['port']:
+            if self.get_option('port'):
                 cmd.append('-p')
-                cmd.append(self.get_option['port'])
+                cmd.append(self.get_option('port'))
 
-            if not self.get_option['ports']:
+            if not self.get_option('ports'):
                 cmd.append('-sP')
 
-            if self.get_option['ipv4'] and not self.get_option['ipv6']:
+            if self.get_option('ipv4') and not self.get_option('ipv6'):
                 cmd.append('-4')
-            elif self.get_option['ipv6'] and not self.get_option['ipv4']:
+            elif self.get_option('ipv6') and not self.get_option('ipv4'):
                 cmd.append('-6')
-            elif not self.get_option['ipv6'] and not self.get_option['ipv4']:
+            elif not self.get_option('ipv6') and not self.get_option('ipv4'):
                 raise AnsibleParserError('One of ipv4 or ipv6 must be enabled for this plugin')
 
-            if self.get_option['exclude']:
+            if self.get_option('exclude'):
                 cmd.append('--exclude')
-                cmd.append(','.join(self.get_option['exclude']))
+                cmd.append(','.join(self.get_option('exclude')))
 
-            if self.get_option['dns_resolve']:
+            if self.get_option('dns_resolve'):
                 cmd.append('-n')
 
-            if self.get_option['udp_scan']:
+            if self.get_option('dns_servers'):
+                cmd.append('--dns-servers')
+                cmd.append(','.join(self.get_option('dns_servers')))
+
+            if self.get_option('udp_scan'):
                 cmd.append('-sU')
 
-            if self.get_option['icmp_timestamp']:
+            if self.get_option('icmp_timestamp'):
                 cmd.append('-PP')
 
-            if self.get_option['open']:
+            if self.get_option('open'):
                 cmd.append('--open')
 
-            if not self.get_option['use_arp_ping']:
+            if not self.get_option('use_arp_ping'):
                 cmd.append('--disable-arp-ping')
 
-            cmd.append(self.get_option['address'])
+            cmd.append(self.get_option('address'))
             try:
                 # execute
                 p = Popen(cmd, stdout=PIPE, stderr=PIPE)
                 stdout, stderr = p.communicate()
                 if p.returncode != 0:
-                    raise AnsibleParserError('Failed to run nmap, rc=%s: %s' % (p.returncode, to_native(stderr)))
+                    raise AnsibleParserError(f'Failed to run nmap, rc={p.returncode}: {to_native(stderr)}')
 
                 # parse results
                 host = None
@@ -254,7 +269,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                 try:
                     t_stdout = to_text(stdout, errors='surrogate_or_strict')
                 except UnicodeError as e:
-                    raise AnsibleParserError('Invalid (non unicode) input returned: %s' % to_native(e))
+                    raise AnsibleParserError(f'Invalid (non unicode) input returned: {e}')
 
                 for line in t_stdout.splitlines():
                     hits = self.find_host.match(line)
@@ -295,7 +310,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                     results[-1]['ports'] = ports
 
             except Exception as e:
-                raise AnsibleParserError("failed to parse %s: %s " % (to_native(path), to_native(e)))
+                raise AnsibleParserError(f"failed to parse {to_native(path)}: {e} ")
 
         if cache_needs_update:
             self._cache[cache_key] = results
