@@ -22,6 +22,10 @@ __metaclass__ = type
 DOCUMENTATION = '''
 ---
 module: ce_vxlan_gateway
+deprecated:
+  removed_in: 6.0.0
+  why: This collection and all content in it is unmaintained and deprecated.
+  alternative: Unknown.
 short_description: Manages gateway for the VXLAN network on HUAWEI CloudEngine devices.
 description:
     - Configuring Centralized All-Active Gateways or Distributed Gateway for
@@ -110,7 +114,7 @@ EXAMPLES = '''
 - name: Vxlan gateway module test
   hosts: ce128
   connection: local
-  gather_facts: no
+  gather_facts: false
 
   tasks:
 
