@@ -11,6 +11,10 @@ __metaclass__ = type
 DOCUMENTATION = '''
 ---
 module: netscaler_cs_vserver
+deprecated:
+  removed_in: 6.0.0
+  why: This collection and all content in it is unmaintained and deprecated.
+  alternative: Unknown.
 short_description: Manage content switching vserver
 description:
     - Manage content switching vserver
