@@ -124,11 +124,12 @@ except ImportError:
 import datetime
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import connect_to_api, vmware_argument_spec
+from ansible_collections.community.vmware.plugins.module_utils.vmware import connect_to_api
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(dict(
         extension_key=dict(type='str', required=True, no_log=False),
         version=dict(type='str', required=True),
