@@ -51,6 +51,12 @@ GET_IDRAC_FIRMWARE_VER_URI = "/redfish/v1/Managers/iDRAC.Embedded.1?$select=Firm
 HOSTNAME_REGEX = r"^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$"
 OME_INFO = "ApplicationService/Info"
 ODATA_ID = "@odata.id"
+POWER_CHECK_RETRIES = 30
+POWER_CHECK_INTERVAL = 10
+GET_IDRAC_FIRMWARE_DETAILS_URI_10 = "/redfish/v1/UpdateService/Oem/Dell/DellSoftwareInventory?$select=Members"
+GET_IDRAC_FIRMWARE_URI_10 = "/redfish/v1/UpdateService/Oem/Dell/DellSoftwareInventory"
+TIMEOUT_NEGATIVE_OR_ZERO_MSG = "The value for the 'job_wait_timeout' parameter cannot be negative or zero."
+INVALID_TIME_FORMAT_MSG = "Invalid value for time. Enter the value in positive integer."
 
 import time
 from datetime import datetime
@@ -364,7 +370,7 @@ def idrac_system_reset(idrac, res_id, payload=None, job_wait=True, wait_time_sec
         time.sleep(10)
         if wait_time_sec:
             resp = idrac.invoke_request(MANAGER_JOB_URI, "GET")
-            job = list(filter(lambda d: d["JobState"] in ["RebootPending"], resp.json_data["Members"]))
+            job = list(filter(lambda d: d["JobState"] in ["RebootPending", "RebootCompleted"], resp.json_data["Members"]))
             if job:
                 job_resp, msg = wait_for_idrac_job_completion(idrac, MANAGER_JOB_ID_URI.format(job[0]["Id"]),
                                                               job_wait=job_wait, wait_timeout=wait_time_sec)
@@ -496,9 +502,9 @@ def get_scheduled_job_resp(idrac_obj, job_type):
     data = {'uri': MANAGER_JOB_URI} if 'uri' in args else {'path': MANAGER_JOB_URI}
     job_list = idrac_obj.invoke_request(method="GET", **data).json_data.get('Members', [])
     if isinstance(job_type, str):
-        job_resp = next((j for j in job_list if (j.get("JobState") in job_state) and (j.get("JobType") == job_type)), None)
+        job_resp = next((j for j in job_list if (j.get("JobState") in job_state) and (j.get("JobType") == job_type)), {})
     elif isinstance(job_type, list):
-        job_resp = next((j for j in job_list if (j.get("JobState") in job_state) and (j.get("JobType") in job_type)), None)
+        job_resp = next((j for j in job_list if (j.get("JobState") in job_state) and (j.get("JobType") in job_type)), {})
     return remove_key(job_resp, regex_pattern='(.*?)@odata')
 
 
@@ -659,3 +665,115 @@ def get_lc_log_or_current_log_time(idrac, curr_time=None, lc_log_ids_list=None,
         msg = "No LC log found."
 
     return lc_log_found, msg
+
+
+def expand_ipv6(ip):
+    sections = ip.split(':')
+    num_sections = len(sections)
+    double_colon_index = sections.index('') if '' in sections else -1
+    if double_colon_index != -1:
+        missing_sections = 8 - num_sections + 1
+        sections[double_colon_index:double_colon_index + 1] = ['0000'] * missing_sections
+    sections = [section.zfill(4) for section in sections]
+    expanded_ip = ':'.join(sections)
+    return expanded_ip
+
+
+def cert_file_format_string(ip, prefix="",
+                            postfix="",
+                            datetime_format="%Y%m%d_%H%M%S"):
+    now = datetime.now()
+    hostname = expand_ipv6(ip).replace(":", ".")
+    data = f"{prefix}{hostname}_{now.strftime(datetime_format)}{postfix}"
+    return data
+
+
+def track_power_state(idrac, base_uri, desired_state, retries=POWER_CHECK_RETRIES, interval=POWER_CHECK_INTERVAL):
+    count = retries
+    while count:
+        ps = get_power_state(idrac, base_uri)
+        if ps in desired_state:
+            achieved = True
+            break
+        else:
+            time.sleep(interval)
+        count = count - 1
+    else:
+        achieved = False
+    return achieved
+
+
+def get_power_state(idrac, base_uri):
+    retries = 10
+    pstate = "Unknown"
+    while retries > 0:
+        try:
+            resp = idrac.invoke_request(base_uri, "GET")
+            pstate = resp.json_data.get("PowerState")
+            break
+        except Exception:
+            retries = retries - 1
+    return pstate
+
+
+def power_act_host(idrac, system_uri, p_state):
+    try:
+        _resp, error_msg = {}, {}
+        uri, error_msg = validate_and_get_first_resource_id_uri(None, idrac, system_uri)
+        if error_msg:
+            return False
+        actions_uri = get_dynamic_uri(idrac, uri, 'Actions').get("#ComputerSystem.Reset", {}).get("target", '')
+        idrac.invoke_request(actions_uri, "POST", data={'ResetType': p_state})
+        p_act = True
+    except HTTPError:
+        p_act = False
+    return p_act
+
+
+def reset_host(idrac, restart_type, system_uri, base_uri):
+    p_state = 'On'
+    ps = get_power_state(idrac, base_uri)
+    on_state = ["On"]
+    if ps in on_state:
+        p_state = 'GracefulShutdown'
+        if 'Force' in restart_type:
+            p_state = 'ForceOff'
+        p_act = power_act_host(idrac, system_uri, p_state)
+        if not p_act:
+            return False
+        state_achieved = track_power_state(idrac, base_uri, ["Off"])
+        p_state = "On"
+        if not state_achieved:
+            time.sleep(10)
+            p_state = "ForceRestart"
+    p_act = power_act_host(idrac, system_uri, p_state)
+    if not p_act:
+        return False
+    state_achieved = track_power_state(idrac, base_uri, on_state)
+    return state_achieved
+
+
+def validate_job_wait(module):
+    """
+    Validates job_wait and job_wait_timeout parameters.
+    :param module: The Ansible module instance.
+    :param job_wait_param: The name of the job wait parameter to check (default is "job_wait").
+    :param job_wait_timeout_param: The name of the job wait timeout parameter to check (default is "job_wait_timeout").
+    """
+    job_wait = module.params.get('job_wait')
+    job_wait_timeout = module.params.get('job_wait_timeout')
+
+    if job_wait and (job_wait_timeout is None or job_wait_timeout <= 0):
+        return True
+
+    return False
+
+
+def validate_time(time, module):
+    # Ensure the time is a string (or cast it to a string if it's not)
+    if not isinstance(time, str):
+        module.exit_json(msg="Time must be a string in HH:MM format", failed=True)
+
+    # Check if the time matches the 24-hour format (HH:MM)
+    if time and not re.match(r"^(?:[01]\d|2[0-3]):[0-5]\d$", time):
+        module.exit_json(msg=INVALID_TIME_FORMAT_MSG, failed=True)
