@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 4.4.0
-# Copyright (C) 2021 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Dell OpenManage Ansible Modules
+# Version 9.3.0
+# Copyright (C) 2022-2024 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -50,18 +50,19 @@ options:
         type: bool
         description:
           - Enables or disables the chassis power button.
-          - If C(False), the chassis cannot be turn on or turn off using the power button.
+          - If C(false), the chassis cannot be turn on or turn off using the power button.
       enable_lcd_override_pin:
         type: bool
         description:
           - Enables or disables the LCD override pin.
-          - This is required when I(enable_chassis_power_button) is C(False).
+          - This is required when I(enable_chassis_power_button) is C(false).
       disabled_button_lcd_override_pin:
-        type: int
+        type: str
         description:
           - The six digit LCD override pin to change the power state of the chassis.
-          - This is required when I(enable_lcd_override_pin) is C(True).
-          - The module will always report change when I(disabled_button_lcd_override_pin) is C(True).
+          - This is required when I(enable_lcd_override_pin) is C(true).
+          - The module will always report change when I(disabled_button_lcd_override_pin) is C(true).
+          - 'The value must be specified in quotes. ex: "001100".'
   quick_sync:
     type: dict
     description:
@@ -84,7 +85,7 @@ options:
         description:
           - Inactivity timeout in seconds or minutes.
           - The range is 120 to 3600 in seconds, or 2 to 60 in minutes.
-          - This option is required when I(enable_inactivity_timeout) is C(True).
+          - This option is required when I(enable_inactivity_timeout) is C(true).
       timeout_limit_unit:
         type: str
         choices: [SECONDS, MINUTES]
@@ -92,7 +93,7 @@ options:
           - Inactivity timeout limit unit.
           - C(SECONDS) to set I(timeout_limit) in seconds.
           - C(MINUTES) to set I(timeout_limit) in minutes.
-          - This option is required when I(enable_inactivity_timeout) is C(True).
+          - This option is required when I(enable_inactivity_timeout) is C(true).
       enable_read_authentication:
         type: bool
         description: Enables or disables the option to log in using your user credentials and to read the
@@ -129,13 +130,14 @@ options:
           - ja to set Japanese language.
           - zh to set Chinese language.
 requirements:
-  - "python >= 2.7.17"
+  - "python >= 3.9.6"
 author:
   - "Felix Stephen (@felixs88)"
+  - "Shivam Sharma (@ShivamSh3)"
 notes:
   - Run this module from a system that has direct access to OpenManage Enterprise Modular.
   - This module supports C(check_mode).
-  - The module will always report change when I(enable_chassis_power_button) is C(True).
+  - The module will always report change when I(enable_chassis_power_button) is C(true).
 """
 
 EXAMPLES = """
@@ -145,19 +147,21 @@ EXAMPLES = """
     hostname: "192.168.0.1"
     username: "username"
     password: "password"
+    ca_path: "/path/to/ca_cert.pem"
     device_id: 25011
     enable_kvm_access: true
     enable_chassis_direct_access: false
     chassis_power_button:
       enable_chassis_power_button: false
       enable_lcd_override_pin: true
-      disabled_button_lcd_override_pin: 123456
+      disabled_button_lcd_override_pin: "123456"
 
 - name: Configure Quick sync and LCD settings of the chassis using device service tag.
   dellemc.openmanage.ome_device_local_access_configuration:
     hostname: "192.168.0.1"
     username: "username"
     password: "password"
+    ca_path: "/path/to/ca_cert.pem"
     device_service_tag: GHRT2RL
     quick_sync:
       quick_sync_access: READ_ONLY
@@ -176,12 +180,13 @@ EXAMPLES = """
     hostname: "192.168.0.1"
     username: "username"
     password: "password"
+    ca_path: "/path/to/ca_cert.pem"
     enable_kvm_access: true
     enable_chassis_direct_access: false
     chassis_power_button:
       enable_chassis_power_button: false
       enable_lcd_override_pin: true
-      disabled_button_lcd_override_pin: 123456
+      disabled_button_lcd_override_pin: "123456"
     quick_sync:
       quick_sync_access: READ_WRITE
       enable_read_authentication: true
@@ -216,9 +221,9 @@ location_details:
     "LcdCustomString": "LCD Text",
     "LcdLanguage": "en",
     "LcdOverridePin": "",
-    "LcdPinLength": null,
+    "LcdPinLength": 6,
     "LcdPresence": "Present",
-    "LedPresence": null,
+    "LedPresence": "Absent",
     "QuickSync": {
       "EnableInactivityTimeout": true,
       "EnableQuickSyncWifi": false,
@@ -256,10 +261,9 @@ import json
 import socket
 import copy
 from ssl import SSLError
-from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 from ansible.module_utils.urls import ConnectionError
-from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME
+from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME, OmeAnsibleModule
 
 DOMAIN_URI = "ManagementDomainService/Domains"
 DEVICE_URI = "DeviceService/Devices"
@@ -375,6 +379,8 @@ def check_mode_validation(module, loc_resp):
     payload["QuickSync"]["QuickSyncHardware"] = loc_resp["QuickSync"]["QuickSyncHardware"]
     payload["SettingType"] = "LocalAccessConfiguration"
     payload["LcdPresence"] = loc_resp["LcdPresence"]
+    payload["LcdPinLength"] = loc_resp["LcdPinLength"]
+    payload["LedPresence"] = loc_resp["LedPresence"]
     return payload
 
 
@@ -414,7 +420,7 @@ def main():
     chassis_power = {
         "enable_chassis_power_button": {"type": "bool", "required": True},
         "enable_lcd_override_pin": {"type": "bool", "required": False},
-        "disabled_button_lcd_override_pin": {"type": "int", "required": False, "no_log": True}}
+        "disabled_button_lcd_override_pin": {"type": "str", "required": False, "no_log": True}}
     quick_sync_options = {
         "quick_sync_access": {"type": "str", "required": False, "choices": ["DISABLED", "READ_ONLY", "READ_WRITE"]},
         "enable_inactivity_timeout": {"type": "bool", "required": False},
@@ -426,28 +432,26 @@ def main():
         "lcd_access": {"type": "str", "required": False, "choices": ["VIEW_AND_MODIFY", "VIEW_ONLY", "DISABLED"]},
         "user_defined": {"type": "str", "required": False},
         "lcd_language": {"type": "str", "required": False}}
-    module = AnsibleModule(
-        argument_spec={
-            "hostname": {"required": True, "type": "str"},
-            "username": {"required": True, "type": "str"},
-            "password": {"required": True, "type": "str", "no_log": True},
-            "port": {"required": False, "type": "int", "default": 443},
-            "device_id": {"required": False, "type": "int"},
-            "device_service_tag": {"required": False, "type": "str"},
-            "enable_kvm_access": {"required": False, "type": "bool"},
-            "enable_chassis_direct_access": {"required": False, "type": "bool"},
-            "chassis_power_button": {
-                "required": False, "type": "dict", "options": chassis_power,
-                "required_if": [["enable_lcd_override_pin", True, ("disabled_button_lcd_override_pin",)]],
-            },
-            "quick_sync": {
-                "required": False, "type": "dict", "options": quick_sync_options,
-                "required_if": [["enable_inactivity_timeout", True, ("timeout_limit", "timeout_limit_unit")]]
-            },
-            "lcd": {
-                "required": False, "type": "dict", "options": lcd_options,
-            },
+    specs = {
+        "device_id": {"required": False, "type": "int"},
+        "device_service_tag": {"required": False, "type": "str"},
+        "enable_kvm_access": {"required": False, "type": "bool"},
+        "enable_chassis_direct_access": {"required": False, "type": "bool"},
+        "chassis_power_button": {
+            "required": False, "type": "dict", "options": chassis_power,
+            "required_if": [["enable_lcd_override_pin", True, ("disabled_button_lcd_override_pin",)]],
         },
+        "quick_sync": {
+            "required": False, "type": "dict", "options": quick_sync_options,
+            "required_if": [["enable_inactivity_timeout", True, ("timeout_limit", "timeout_limit_unit")]]
+        },
+        "lcd": {
+            "required": False, "type": "dict", "options": lcd_options,
+        },
+    }
+
+    module = OmeAnsibleModule(
+        argument_spec=specs,
         mutually_exclusive=[('device_id', 'device_service_tag')],
         required_one_of=[["enable_kvm_access", "enable_chassis_direct_access",
                           "chassis_power_button", "quick_sync", "lcd"]],
@@ -469,11 +473,11 @@ def main():
                 resp_data["QuickSync"]["TimeoutLimitUnit"] = "MINUTES"
             module.exit_json(msg=SUCCESS_MSG, local_access_settings=resp_data, changed=True)
     except HTTPError as err:
-        module.fail_json(msg=str(err), error_info=json.load(err))
+        module.exit_json(msg=str(err), error_info=json.load(err), failed=True)
     except URLError as err:
         module.exit_json(msg=str(err), unreachable=True)
-    except (IOError, ValueError, SSLError, TypeError, ConnectionError, AttributeError, IndexError, KeyError) as err:
-        module.fail_json(msg=str(err))
+    except (IOError, ValueError, SSLError, TypeError, ConnectionError, AttributeError, IndexError, KeyError, OSError) as err:
+        module.exit_json(msg=str(err), failed=True)
 
 
 if __name__ == '__main__':
