@@ -105,9 +105,10 @@ options:
                             - 'incoming'
                             - 'outgoing'
                             - 'any'
-                    file-type:
+                    file_type:
+                        aliases: ['file-type']
                         type: raw
-                        description: (list or str) Deprecated, please rename it to file_type. Select file type.
+                        description: (list or str) Select file type.
                     filter:
                         type: str
                         description: Add a file filter.
@@ -150,17 +151,16 @@ EXAMPLES = '''
         adom: <your own value>
         profile: <your own value>
         cifs_profile_filefilter:
-          entries:
-            -
-              action: <value in [block, log]>
-              comment: <string>
-              direction: <value in [incoming, outgoing, any]>
-              file_type: <list or string>
-              filter: <string>
-              protocol:
-                - cifs
-          log: <value in [disable, enable]>
-          status: <value in [disable, enable]>
+          # entries:
+          #   - action: <value in [block, log]>
+          #     comment: <string>
+          #     direction: <value in [incoming, outgoing, any]>
+          #     file_type: <list or string>
+          #     filter: <string>
+          #     protocol:
+          #       - "cifs"
+          # log: <value in [disable, enable]>
+          # status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -204,23 +204,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/cifs/profile/{profile}/file-filter',
         '/pm/config/global/obj/cifs/profile/{profile}/file-filter'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/cifs/profile/{profile}/file-filter/{file-filter}',
-        '/pm/config/global/obj/cifs/profile/{profile}/file-filter/{file-filter}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = None
     module_arg_spec = {
@@ -246,7 +238,6 @@ def main():
                 'log': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'status': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -260,9 +251,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
