@@ -102,9 +102,10 @@ options:
                     - 'none'
                     - 'http'
                     - '8bit'
-            msg-type:
+            msg_type:
+                aliases: ['msg-type']
                 type: str
-                description: Deprecated, please rename it to msg_type. Message type.
+                description: Message type.
 '''
 
 EXAMPLES = '''
@@ -126,10 +127,10 @@ EXAMPLES = '''
         adom: <your own value>
         devprof: <your own value>
         devprof_system_replacemsg_devicedetectionportal:
-          buffer: <string>
-          format: <value in [none, text, html, ...]>
-          header: <value in [none, http, 8bit]>
-          msg_type: <string>
+          # buffer: <string>
+          # format: <value in [none, text, html, ...]>
+          # header: <value in [none, http, 8bit]>
+          # msg_type: <string>
 '''
 
 RETURN = '''
@@ -173,21 +174,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/devprof/{devprof}/system/replacemsg/device-detection-portal'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/devprof/{devprof}/system/replacemsg/device-detection-portal/{device-detection-portal}'
-    ]
-
     url_params = ['adom', 'devprof']
     module_primary_key = None
     module_arg_spec = {
@@ -202,7 +196,6 @@ def main():
                 'header': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'choices': ['none', 'http', '8bit'], 'type': 'str'},
                 'msg-type': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -216,9 +209,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
