@@ -112,9 +112,10 @@ options:
                     id:
                         type: int
                         description: Mime header entry ID.
-                    pattern-type:
+                    pattern_type:
+                        aliases: ['pattern-type']
                         type: str
-                        description: Deprecated, please rename it to pattern_type. Wildcard pattern or regular expression.
+                        description: Wildcard pattern or regular expression.
                         choices:
                             - 'wildcard'
                             - 'regexp'
@@ -152,17 +153,16 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         emailfilter_mheader:
-          comment: <string>
-          entries:
-            -
-              action: <value in [spam, clear]>
-              fieldbody: <string>
-              fieldname: <string>
-              id: <integer>
-              pattern_type: <value in [wildcard, regexp]>
-              status: <value in [disable, enable]>
-          id: <integer>
-          name: <string>
+          id: 0 # Required variable, integer
+          # comment: <string>
+          # entries:
+          #   - action: <value in [spam, clear]>
+          #     fieldbody: <string>
+          #     fieldname: <string>
+          #     id: <integer>
+          #     pattern_type: <value in [wildcard, regexp]>
+          #     status: <value in [disable, enable]>
+          # name: <string>
 '''
 
 RETURN = '''
@@ -206,23 +206,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/emailfilter/mheader',
         '/pm/config/global/obj/emailfilter/mheader'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/emailfilter/mheader/{mheader}',
-        '/pm/config/global/obj/emailfilter/mheader/{mheader}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -248,7 +240,6 @@ def main():
                 'id': {'v_range': [['6.2.0', '']], 'required': True, 'type': 'int'},
                 'name': {'v_range': [['6.2.0', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -262,9 +253,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
