@@ -97,12 +97,14 @@ options:
                 type: str
                 description: IP.
                 required: true
-            net-id:
+            net_id:
+                aliases: ['net-id']
                 type: str
-                description: Deprecated, please rename it to net_id. Network ID.
-            obj-id:
+                description: Network ID.
+            obj_id:
+                aliases: ['obj-id']
                 type: str
-                description: Deprecated, please rename it to obj_id. Object ID.
+                description: Object ID.
 '''
 
 EXAMPLES = '''
@@ -125,9 +127,9 @@ EXAMPLES = '''
         address: <your own value>
         state: present # <value in [present, absent]>
         firewall_address_list:
-          ip: <string>
-          net_id: <string>
-          obj_id: <string>
+          ip: "your value" # Required variable, string
+          # net_id: <string>
+          # obj_id: <string>
 '''
 
 RETURN = '''
@@ -171,23 +173,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/address/{address}/list',
         '/pm/config/global/obj/firewall/address/{address}/list'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/address/{address}/list/{list}',
-        '/pm/config/global/obj/firewall/address/{address}/list/{list}'
-    ]
-
     url_params = ['adom', 'address']
     module_primary_key = 'ip'
     module_arg_spec = {
@@ -201,7 +195,6 @@ def main():
                 'net-id': {'v_range': [['6.2.0', '']], 'type': 'str'},
                 'obj-id': {'v_range': [['6.2.0', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -210,17 +203,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_address_list'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
