@@ -100,9 +100,10 @@ options:
                 type: int
                 description: ID.
                 required: true
-            rate-limit:
+            rate_limit:
+                aliases: ['rate-limit']
                 type: int
-                description: Deprecated, please rename it to rate_limit. Rate limit
+                description: Rate limit
             version:
                 type: int
                 description: GTP version number
@@ -187,23 +188,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/gtp/{gtp}/per-apn-shaper',
         '/pm/config/global/obj/firewall/gtp/{gtp}/per-apn-shaper'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/gtp/{gtp}/per-apn-shaper/{per-apn-shaper}',
-        '/pm/config/global/obj/firewall/gtp/{gtp}/per-apn-shaper/{per-apn-shaper}'
-    ]
-
     url_params = ['adom', 'gtp']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -213,7 +206,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'apn': {'type': 'str'}, 'id': {'required': True, 'type': 'int'}, 'rate-limit': {'type': 'int'}, 'version': {'type': 'int'}}
-
         }
     }
 
@@ -227,9 +219,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
