@@ -84,36 +84,44 @@ options:
         required: false
         type: dict
         suboptions:
-            ack-delay-exponent:
+            ack_delay_exponent:
+                aliases: ['ack-delay-exponent']
                 type: int
-                description: Deprecated, please rename it to ack_delay_exponent. ACK delay exponent
-            active-connection-id-limit:
+                description: ACK delay exponent
+            active_connection_id_limit:
+                aliases: ['active-connection-id-limit']
                 type: int
-                description: Deprecated, please rename it to active_connection_id_limit. Active connection ID limit
-            active-migration:
+                description: Active connection ID limit
+            active_migration:
+                aliases: ['active-migration']
                 type: str
-                description: Deprecated, please rename it to active_migration. Enable/disable active migration
+                description: Enable/disable active migration
                 choices:
                     - 'disable'
                     - 'enable'
-            grease-quic-bit:
+            grease_quic_bit:
+                aliases: ['grease-quic-bit']
                 type: str
-                description: Deprecated, please rename it to grease_quic_bit. Enable/disable grease QUIC bit
+                description: Enable/disable grease QUIC bit
                 choices:
                     - 'disable'
                     - 'enable'
-            max-ack-delay:
+            max_ack_delay:
+                aliases: ['max-ack-delay']
                 type: int
-                description: Deprecated, please rename it to max_ack_delay. Maximum ACK delay in milliseconds
-            max-datagram-frame-size:
+                description: Maximum ACK delay in milliseconds
+            max_datagram_frame_size:
+                aliases: ['max-datagram-frame-size']
                 type: int
-                description: Deprecated, please rename it to max_datagram_frame_size. Maximum datagram frame size in bytes
-            max-idle-timeout:
+                description: Maximum datagram frame size in bytes
+            max_idle_timeout:
+                aliases: ['max-idle-timeout']
                 type: int
-                description: Deprecated, please rename it to max_idle_timeout. Maximum idle timeout milliseconds
-            max-udp-payload-size:
+                description: Maximum idle timeout milliseconds
+            max_udp_payload_size:
+                aliases: ['max-udp-payload-size']
                 type: int
-                description: Deprecated, please rename it to max_udp_payload_size. Maximum UDP payload size in bytes
+                description: Maximum UDP payload size in bytes
 '''
 
 EXAMPLES = '''
@@ -135,14 +143,14 @@ EXAMPLES = '''
         adom: <your own value>
         vip: <your own value>
         firewall_vip_quic:
-          ack_delay_exponent: <integer>
-          active_connection_id_limit: <integer>
-          active_migration: <value in [disable, enable]>
-          grease_quic_bit: <value in [disable, enable]>
-          max_ack_delay: <integer>
-          max_datagram_frame_size: <integer>
-          max_idle_timeout: <integer>
-          max_udp_payload_size: <integer>
+          # ack_delay_exponent: <integer>
+          # active_connection_id_limit: <integer>
+          # active_migration: <value in [disable, enable]>
+          # grease_quic_bit: <value in [disable, enable]>
+          # max_ack_delay: <integer>
+          # max_datagram_frame_size: <integer>
+          # max_idle_timeout: <integer>
+          # max_udp_payload_size: <integer>
 '''
 
 RETURN = '''
@@ -186,23 +194,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/vip/{vip}/quic',
         '/pm/config/global/obj/firewall/vip/{vip}/quic'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/vip/{vip}/quic/{quic}',
-        '/pm/config/global/obj/firewall/vip/{vip}/quic/{quic}'
-    ]
-
     url_params = ['adom', 'vip']
     module_primary_key = None
     module_arg_spec = {
@@ -221,7 +221,6 @@ def main():
                 'max-idle-timeout': {'v_range': [['7.4.1', '']], 'type': 'int'},
                 'max-udp-payload-size': {'v_range': [['7.4.1', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -235,9 +234,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
