@@ -96,9 +96,10 @@ options:
                 type: str
                 description: Name.
                 required: true
-            onboarding-vlan:
+            onboarding_vlan:
+                aliases: ['onboarding-vlan']
                 type: str
-                description: Deprecated, please rename it to onboarding_vlan. VLAN interface name.
+                description: VLAN interface name.
 '''
 
 EXAMPLES = '''
@@ -120,9 +121,9 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         nacprofile:
-          comment: <string>
-          name: <string>
-          onboarding_vlan: <string>
+          name: "your value" # Required variable, string
+          # comment: <string>
+          # onboarding_vlan: <string>
 '''
 
 RETURN = '''
@@ -166,23 +167,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/wireless-controller/nac-profile',
         '/pm/config/global/obj/wireless-controller/nac-profile'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/wireless-controller/nac-profile/{nac-profile}',
-        '/pm/config/global/obj/wireless-controller/nac-profile/{nac-profile}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -195,7 +188,6 @@ def main():
                 'name': {'v_range': [['7.0.3', '']], 'required': True, 'type': 'str'},
                 'onboarding-vlan': {'v_range': [['7.0.3', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -209,9 +201,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
