@@ -99,13 +99,13 @@ options:
         suboptions:
             attr:
                 type: str
-                description: No description.
+                description: Attr.
                 choices:
                     - 'label'
                     - 'global-label'
             name:
                 type: str
-                description: No description.
+                description: Name.
 '''
 
 EXAMPLES = '''
@@ -129,8 +129,8 @@ EXAMPLES = '''
         policy: <your own value>
         state: present # <value in [present, absent]>
         pkg_firewall_consolidated_policy_sectionvalue:
-          attr: <value in [label, global-label]>
-          name: <string>
+          # attr: <value in [label, global-label]>
+          # name: <string>
 '''
 
 RETURN = '''
@@ -174,21 +174,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/pkg/{pkg}/firewall/consolidated/policy/{policy}/section value'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/pkg/{pkg}/firewall/consolidated/policy/{policy}/section value'
-    ]
-
     url_params = ['adom', 'pkg', 'policy']
     module_primary_key = None
     module_arg_spec = {
@@ -202,7 +195,6 @@ def main():
                 'attr': {'v_range': [['6.2.5', '']], 'choices': ['label', 'global-label'], 'type': 'str'},
                 'name': {'v_range': [['6.2.5', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -211,17 +203,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pkg_firewall_consolidated_policy_sectionvalue'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('object member', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_object_member()
 
     module.exit_json(meta=module.params)
 
