@@ -99,7 +99,7 @@ options:
             rule:
                 type: list
                 elements: dict
-                description: No description.
+                description: Rule.
                 suboptions:
                     action:
                         type: str
@@ -107,15 +107,16 @@ options:
                         choices:
                             - 'permit'
                             - 'deny'
-                    exact-match:
+                    exact_match:
+                        aliases: ['exact-match']
                         type: str
-                        description: Deprecated, please rename it to exact_match. Enable/disable exact prefix match.
+                        description: Enable/disable exact prefix match.
                         choices:
                             - 'disable'
                             - 'enable'
                     flags:
                         type: int
-                        description: No description.
+                        description: Flags.
                     id:
                         type: int
                         description: Rule ID.
@@ -143,15 +144,14 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         router_accesslist6:
-          comments: <string>
-          name: <string>
-          rule:
-            -
-              action: <value in [permit, deny]>
-              exact_match: <value in [disable, enable]>
-              flags: <integer>
-              id: <integer>
-              prefix6: <string>
+          name: "your value" # Required variable, string
+          # comments: <string>
+          # rule:
+          #   - action: <value in [permit, deny]>
+          #     exact_match: <value in [disable, enable]>
+          #     flags: <integer>
+          #     id: <integer>
+          #     prefix6: <string>
 '''
 
 RETURN = '''
@@ -195,23 +195,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/router/access-list6',
         '/pm/config/global/obj/router/access-list6'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/router/access-list6/{access-list6}',
-        '/pm/config/global/obj/router/access-list6/{access-list6}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -235,7 +227,6 @@ def main():
                     'elements': 'dict'
                 }
             }
-
         }
     }
 
@@ -244,17 +235,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'router_accesslist6'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
