@@ -108,13 +108,12 @@ EXAMPLES = '''
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         securityconsole_template_cli_preview:
-          adom: <string>
-          filename: <string>
-          pkg: <string>
-          scope:
-            -
-              name: <string>
-              vdom: <string>
+          # adom: <string>
+          # filename: <string>
+          # pkg: <string>
+          # scope:
+          #   - name: <string>
+          #     vdom: <string>
 '''
 
 RETURN = '''
@@ -158,21 +157,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/securityconsole/template/cli/preview'
     ]
-
-    perobject_jrpc_urls = [
-        '/securityconsole/template/cli/preview/{preview}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -190,7 +182,6 @@ def main():
                     'elements': 'dict'
                 }
             }
-
         }
     }
 
@@ -204,9 +195,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('exec', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_exec(argument_specs=module_arg_spec)
+    fmgr.process_exec()
 
     module.exit_json(meta=module.params)
 
