@@ -113,7 +113,7 @@ EXAMPLES = '''
         profile: <your own value>
         state: present # <value in [present, absent]>
         system_admin_profile_writepasswdprofiles:
-          profileid: <string>
+          # profileid: <string>
 '''
 
 RETURN = '''
