@@ -117,8 +117,8 @@ EXAMPLES = '''
         user: <your own value>
         state: present # <value in [present, absent]>
         system_admin_user_dashboardtabs:
-          name: <string>
-          tabid: <integer>
+          name: "your value" # Required variable, string
+          # tabid: <integer>
 '''
 
 RETURN = '''
@@ -162,21 +162,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/admin/user/{user}/dashboard-tabs'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/admin/user/{user}/dashboard-tabs/{dashboard-tabs}'
-    ]
-
     url_params = ['user']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -185,7 +178,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'name': {'required': True, 'type': 'str'}, 'tabid': {'type': 'int'}}
-
         }
     }
 
@@ -199,9 +191,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
