@@ -89,9 +89,10 @@ options:
         required: false
         type: dict
         suboptions:
-            policy-package-name:
+            policy_package_name:
+                aliases: ['policy-package-name']
                 type: str
-                description: Deprecated, please rename it to policy_package_name. Policy package names.
+                description: Policy package names.
                 required: true
 '''
 
@@ -114,7 +115,7 @@ EXAMPLES = '''
         user: <your own value>
         state: present # <value in [present, absent]>
         system_admin_user_policypackage:
-          policy_package_name: <string>
+          policy_package_name: "your value" # Required variable, string
 '''
 
 RETURN = '''
@@ -158,21 +159,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/admin/user/{user}/policy-package'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/admin/user/{user}/policy-package/{policy-package}'
-    ]
-
     url_params = ['user']
     module_primary_key = 'policy-package-name'
     module_arg_spec = {
@@ -181,7 +175,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'policy-package-name': {'required': True, 'type': 'str'}}
-
         }
     }
 
@@ -195,9 +188,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
