@@ -76,9 +76,10 @@ options:
         required: false
         type: dict
         suboptions:
-            dlp-files-auto-deletion:
+            dlp_files_auto_deletion:
+                aliases: ['dlp-files-auto-deletion']
                 type: dict
-                description: Deprecated, please rename it to dlp_files_auto_deletion. Dlp files auto deletion.
+                description: Dlp files auto deletion.
                 suboptions:
                     retention:
                         type: str
@@ -106,9 +107,10 @@ options:
                     value:
                         type: int
                         description: Automatic deletion in x days, weeks, or months.
-            log-auto-deletion:
+            log_auto_deletion:
+                aliases: ['log-auto-deletion']
                 type: dict
-                description: Deprecated, please rename it to log_auto_deletion. Log auto deletion.
+                description: Log auto deletion.
                 suboptions:
                     retention:
                         type: str
@@ -136,9 +138,10 @@ options:
                     value:
                         type: int
                         description: Automatic deletion in x days, weeks, or months.
-            quarantine-files-auto-deletion:
+            quarantine_files_auto_deletion:
+                aliases: ['quarantine-files-auto-deletion']
                 type: dict
-                description: Deprecated, please rename it to quarantine_files_auto_deletion. Quarantine files auto deletion.
+                description: Quarantine files auto deletion.
                 suboptions:
                     retention:
                         type: str
@@ -166,9 +169,10 @@ options:
                     value:
                         type: int
                         description: Automatic deletion in x days, weeks, or months.
-            report-auto-deletion:
+            report_auto_deletion:
+                aliases: ['report-auto-deletion']
                 type: dict
-                description: Deprecated, please rename it to report_auto_deletion. Report auto deletion.
+                description: Report auto deletion.
                 suboptions:
                     retention:
                         type: str
@@ -196,9 +200,10 @@ options:
                     value:
                         type: int
                         description: Automatic deletion in x days, weeks, or months.
-            status-fake:
+            status_fake:
+                aliases: ['status-fake']
                 type: int
-                description: Deprecated, please rename it to status_fake. Fake value for the menu to work.
+                description: Fake value for the menu to work.
 '''
 
 EXAMPLES = '''
@@ -218,27 +223,27 @@ EXAMPLES = '''
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_autodelete:
-          dlp_files_auto_deletion:
-            retention: <value in [days, weeks, months]>
-            runat: <integer>
-            status: <value in [disable, enable]>
-            value: <integer>
-          log_auto_deletion:
-            retention: <value in [days, weeks, months]>
-            runat: <integer>
-            status: <value in [disable, enable]>
-            value: <integer>
-          quarantine_files_auto_deletion:
-            retention: <value in [days, weeks, months]>
-            runat: <integer>
-            status: <value in [disable, enable]>
-            value: <integer>
-          report_auto_deletion:
-            retention: <value in [days, weeks, months]>
-            runat: <integer>
-            status: <value in [disable, enable]>
-            value: <integer>
-          status_fake: <integer>
+          # dlp_files_auto_deletion:
+          #   retention: <value in [days, weeks, months]>
+          #   runat: <integer>
+          #   status: <value in [disable, enable]>
+          #   value: <integer>
+          # log_auto_deletion:
+          #   retention: <value in [days, weeks, months]>
+          #   runat: <integer>
+          #   status: <value in [disable, enable]>
+          #   value: <integer>
+          # quarantine_files_auto_deletion:
+          #   retention: <value in [days, weeks, months]>
+          #   runat: <integer>
+          #   status: <value in [disable, enable]>
+          #   value: <integer>
+          # report_auto_deletion:
+          #   retention: <value in [days, weeks, months]>
+          #   runat: <integer>
+          #   status: <value in [disable, enable]>
+          #   value: <integer>
+          # status_fake: <integer>
 '''
 
 RETURN = '''
@@ -282,21 +287,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/auto-delete'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/auto-delete/{auto-delete}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -342,7 +340,6 @@ def main():
                 },
                 'status-fake': {'type': 'int'}
             }
-
         }
     }
 
@@ -356,9 +353,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
