@@ -95,16 +95,18 @@ options:
         required: false
         type: dict
         suboptions:
-            end-ip:
+            end_ip:
+                aliases: ['end-ip']
                 type: str
-                description: Deprecated, please rename it to end_ip. Ending IP address, inclusive, of the address range
+                description: Ending IP address, inclusive, of the address range
             id:
                 type: int
                 description: ID of individual entry in the IPv6 range table.
                 required: true
-            start-ip:
+            start_ip:
+                aliases: ['start-ip']
                 type: str
-                description: Deprecated, please rename it to start_ip. Starting IP address, inclusive, of the address range
+                description: Starting IP address, inclusive, of the address range
 '''
 
 EXAMPLES = '''
@@ -127,9 +129,9 @@ EXAMPLES = '''
         geoip_override: <your own value>
         state: present # <value in [present, absent]>
         system_geoipoverride_ip6range:
-          end_ip: <string>
-          id: <integer>
-          start_ip: <string>
+          id: 0 # Required variable, integer
+          # end_ip: <string>
+          # start_ip: <string>
 '''
 
 RETURN = '''
@@ -173,23 +175,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/geoip-override/{geoip-override}/ip6-range',
         '/pm/config/global/obj/system/geoip-override/{geoip-override}/ip6-range'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/geoip-override/{geoip-override}/ip6-range/{ip6-range}',
-        '/pm/config/global/obj/system/geoip-override/{geoip-override}/ip6-range/{ip6-range}'
-    ]
-
     url_params = ['adom', 'geoip-override']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -204,7 +198,6 @@ def main():
                 'id': {'v_range': [['6.4.0', '']], 'required': True, 'type': 'int'},
                 'start-ip': {'v_range': [['6.4.0', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -218,9 +211,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
