@@ -168,9 +168,10 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            syslog-name:
+            syslog_name:
+                aliases: ['syslog-name']
                 type: str
-                description: Deprecated, please rename it to syslog_name. Remote syslog server name.
+                description: Remote syslog server name.
             cert:
                 type: str
                 description: Select local certificate used for secure connection.
@@ -183,10 +184,10 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            secure-connection:
+            secure_connection:
+                aliases: ['secure-connection']
                 type: str
                 description:
-                    - Deprecated, please rename it to secure_connection.
                     - Enable/disable connection secured by TLS/SSL.
                     - disable - Disable SSL connection.
                     - enable - Enable SSL connection.
@@ -212,14 +213,14 @@ EXAMPLES = '''
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_locallog_syslogd3_setting:
-          csv: <value in [disable, enable]>
-          facility: <value in [kernel, user, ntp, ...]>
-          severity: <value in [emergency, alert, critical, ...]>
-          status: <value in [disable, enable]>
-          syslog_name: <string>
-          cert: <string>
-          reliable: <value in [disable, enable]>
-          secure_connection: <value in [disable, enable]>
+          # csv: <value in [disable, enable]>
+          # facility: <value in [kernel, user, ntp, ...]>
+          # severity: <value in [emergency, alert, critical, ...]>
+          # status: <value in [disable, enable]>
+          # syslog_name: <string>
+          # cert: <string>
+          # reliable: <value in [disable, enable]>
+          # secure_connection: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -263,21 +264,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/locallog/syslogd3/setting'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/locallog/syslogd3/setting/{setting}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -296,11 +290,10 @@ def main():
                 'severity': {'choices': ['emergency', 'alert', 'critical', 'error', 'warning', 'notification', 'information', 'debug'], 'type': 'str'},
                 'status': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'syslog-name': {'type': 'str'},
-                'cert': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '7.4.2']], 'type': 'str'},
-                'reliable': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '7.4.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'secure-connection': {'v_range': [['6.4.6', '6.4.14'], ['7.0.1', '7.4.2']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'cert': {'v_range': [['6.4.6', '6.4.15'], ['7.0.1', '7.4.2']], 'type': 'str'},
+                'reliable': {'v_range': [['6.4.6', '6.4.15'], ['7.0.1', '7.4.2']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'secure-connection': {'v_range': [['6.4.6', '6.4.15'], ['7.0.1', '7.4.2']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -314,9 +307,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
