@@ -89,162 +89,190 @@ options:
             act:
                 type: int
                 description: Tcam tact act.
-            act-v:
+            act_v:
+                aliases: ['act-v']
                 type: str
-                description: Deprecated, please rename it to act_v. Enable to set tact act.
+                description: Enable to set tact act.
                 choices:
                     - 'disable'
                     - 'enable'
-            fmtuv4-s:
+            fmtuv4_s:
+                aliases: ['fmtuv4-s']
                 type: int
-                description: Deprecated, please rename it to fmtuv4_s. Tcam tact fmtuv4-s.
-            fmtuv4-s-v:
+                description: Tcam tact fmtuv4-s.
+            fmtuv4_s_v:
+                aliases: ['fmtuv4-s-v']
                 type: str
-                description: Deprecated, please rename it to fmtuv4_s_v. Enable to set tact fmtuv4-s.
+                description: Enable to set tact fmtuv4-s.
                 choices:
                     - 'disable'
                     - 'enable'
-            fmtuv6-s:
+            fmtuv6_s:
+                aliases: ['fmtuv6-s']
                 type: int
-                description: Deprecated, please rename it to fmtuv6_s. Tcam tact fmtuv6-s.
-            fmtuv6-s-v:
+                description: Tcam tact fmtuv6-s.
+            fmtuv6_s_v:
+                aliases: ['fmtuv6-s-v']
                 type: str
-                description: Deprecated, please rename it to fmtuv6_s_v. Enable to set tact fmtuv6-s.
+                description: Enable to set tact fmtuv6-s.
                 choices:
                     - 'disable'
                     - 'enable'
             lnkid:
                 type: int
                 description: Tcam tact lnkid.
-            lnkid-v:
+            lnkid_v:
+                aliases: ['lnkid-v']
                 type: str
-                description: Deprecated, please rename it to lnkid_v. Enable to set tact lnkid.
+                description: Enable to set tact lnkid.
                 choices:
                     - 'disable'
                     - 'enable'
-            mac-id:
+            mac_id:
+                aliases: ['mac-id']
                 type: int
-                description: Deprecated, please rename it to mac_id. Tcam tact mac-id.
-            mac-id-v:
+                description: Tcam tact mac-id.
+            mac_id_v:
+                aliases: ['mac-id-v']
                 type: str
-                description: Deprecated, please rename it to mac_id_v. Enable to set tact mac-id.
+                description: Enable to set tact mac-id.
                 choices:
                     - 'disable'
                     - 'enable'
-            mss-t:
+            mss_t:
+                aliases: ['mss-t']
                 type: int
-                description: Deprecated, please rename it to mss_t. Tcam tact mss.
-            mss-t-v:
+                description: Tcam tact mss.
+            mss_t_v:
+                aliases: ['mss-t-v']
                 type: str
-                description: Deprecated, please rename it to mss_t_v. Enable to set tact mss.
+                description: Enable to set tact mss.
                 choices:
                     - 'disable'
                     - 'enable'
             mtuv4:
                 type: int
                 description: Tcam tact mtuv4.
-            mtuv4-v:
+            mtuv4_v:
+                aliases: ['mtuv4-v']
                 type: str
-                description: Deprecated, please rename it to mtuv4_v. Enable to set tact mtuv4.
+                description: Enable to set tact mtuv4.
                 choices:
                     - 'disable'
                     - 'enable'
             mtuv6:
                 type: int
                 description: Tcam tact mtuv6.
-            mtuv6-v:
+            mtuv6_v:
+                aliases: ['mtuv6-v']
                 type: str
-                description: Deprecated, please rename it to mtuv6_v. Enable to set tact mtuv6.
+                description: Enable to set tact mtuv6.
                 choices:
                     - 'disable'
                     - 'enable'
-            slif-act:
+            slif_act:
+                aliases: ['slif-act']
                 type: int
-                description: Deprecated, please rename it to slif_act. Tcam tact slif-act.
-            slif-act-v:
+                description: Tcam tact slif-act.
+            slif_act_v:
+                aliases: ['slif-act-v']
                 type: str
-                description: Deprecated, please rename it to slif_act_v. Enable to set tact slif-act.
+                description: Enable to set tact slif-act.
                 choices:
                     - 'disable'
                     - 'enable'
             sublnkid:
                 type: int
                 description: Tcam tact sublnkid.
-            sublnkid-v:
+            sublnkid_v:
+                aliases: ['sublnkid-v']
                 type: str
-                description: Deprecated, please rename it to sublnkid_v. Enable to set tact sublnkid.
+                description: Enable to set tact sublnkid.
                 choices:
                     - 'disable'
                     - 'enable'
-            tgtv-act:
+            tgtv_act:
+                aliases: ['tgtv-act']
                 type: int
-                description: Deprecated, please rename it to tgtv_act. Tcam tact tgtv-act.
-            tgtv-act-v:
+                description: Tcam tact tgtv-act.
+            tgtv_act_v:
+                aliases: ['tgtv-act-v']
                 type: str
-                description: Deprecated, please rename it to tgtv_act_v. Enable to set tact tgtv-act.
+                description: Enable to set tact tgtv-act.
                 choices:
                     - 'disable'
                     - 'enable'
-            tlif-act:
+            tlif_act:
+                aliases: ['tlif-act']
                 type: int
-                description: Deprecated, please rename it to tlif_act. Tcam tact tlif-act.
-            tlif-act-v:
+                description: Tcam tact tlif-act.
+            tlif_act_v:
+                aliases: ['tlif-act-v']
                 type: str
-                description: Deprecated, please rename it to tlif_act_v. Enable to set tact tlif-act.
+                description: Enable to set tact tlif-act.
                 choices:
                     - 'disable'
                     - 'enable'
             tpeid:
                 type: int
                 description: Tcam tact tpeid.
-            tpeid-v:
+            tpeid_v:
+                aliases: ['tpeid-v']
                 type: str
-                description: Deprecated, please rename it to tpeid_v. Enable to set tact tpeid.
+                description: Enable to set tact tpeid.
                 choices:
                     - 'disable'
                     - 'enable'
             v6fe:
                 type: int
                 description: Tcam tact v6fe.
-            v6fe-v:
+            v6fe_v:
+                aliases: ['v6fe-v']
                 type: str
-                description: Deprecated, please rename it to v6fe_v. Enable to set tact v6fe.
+                description: Enable to set tact v6fe.
                 choices:
                     - 'disable'
                     - 'enable'
-            vep-en-v:
+            vep_en_v:
+                aliases: ['vep-en-v']
                 type: str
-                description: Deprecated, please rename it to vep_en_v. Enable to set tact vep-en.
+                description: Enable to set tact vep-en.
                 choices:
                     - 'disable'
                     - 'enable'
-            vep-slid:
+            vep_slid:
+                aliases: ['vep-slid']
                 type: int
-                description: Deprecated, please rename it to vep_slid. Tcam tact vep_slid.
-            vep-slid-v:
+                description: Tcam tact vep_slid.
+            vep_slid_v:
+                aliases: ['vep-slid-v']
                 type: str
-                description: Deprecated, please rename it to vep_slid_v. Enable to set tact vep-slid.
+                description: Enable to set tact vep-slid.
                 choices:
                     - 'disable'
                     - 'enable'
             vep_en:
                 type: int
                 description: Tcam tact vep_en.
-            xlt-lif:
+            xlt_lif:
+                aliases: ['xlt-lif']
                 type: int
-                description: Deprecated, please rename it to xlt_lif. Tcam tact xlt-lif.
-            xlt-lif-v:
+                description: Tcam tact xlt-lif.
+            xlt_lif_v:
+                aliases: ['xlt-lif-v']
                 type: str
-                description: Deprecated, please rename it to xlt_lif_v. Enable to set tact xlt-lif.
+                description: Enable to set tact xlt-lif.
                 choices:
                     - 'disable'
                     - 'enable'
-            xlt-vid:
+            xlt_vid:
+                aliases: ['xlt-vid']
                 type: int
-                description: Deprecated, please rename it to xlt_vid. Tcam tact xlt-vid.
-            xlt-vid-v:
+                description: Tcam tact xlt-vid.
+            xlt_vid_v:
+                aliases: ['xlt-vid-v']
                 type: str
-                description: Deprecated, please rename it to xlt_vid_v. Enable to set tact xlt-vid.
+                description: Enable to set tact xlt-vid.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -269,42 +297,42 @@ EXAMPLES = '''
         adom: <your own value>
         npu_tcam: <your own value>
         system_npu_nputcam_tact:
-          act: <integer>
-          act_v: <value in [disable, enable]>
-          fmtuv4_s: <integer>
-          fmtuv4_s_v: <value in [disable, enable]>
-          fmtuv6_s: <integer>
-          fmtuv6_s_v: <value in [disable, enable]>
-          lnkid: <integer>
-          lnkid_v: <value in [disable, enable]>
-          mac_id: <integer>
-          mac_id_v: <value in [disable, enable]>
-          mss_t: <integer>
-          mss_t_v: <value in [disable, enable]>
-          mtuv4: <integer>
-          mtuv4_v: <value in [disable, enable]>
-          mtuv6: <integer>
-          mtuv6_v: <value in [disable, enable]>
-          slif_act: <integer>
-          slif_act_v: <value in [disable, enable]>
-          sublnkid: <integer>
-          sublnkid_v: <value in [disable, enable]>
-          tgtv_act: <integer>
-          tgtv_act_v: <value in [disable, enable]>
-          tlif_act: <integer>
-          tlif_act_v: <value in [disable, enable]>
-          tpeid: <integer>
-          tpeid_v: <value in [disable, enable]>
-          v6fe: <integer>
-          v6fe_v: <value in [disable, enable]>
-          vep_en_v: <value in [disable, enable]>
-          vep_slid: <integer>
-          vep_slid_v: <value in [disable, enable]>
-          vep_en: <integer>
-          xlt_lif: <integer>
-          xlt_lif_v: <value in [disable, enable]>
-          xlt_vid: <integer>
-          xlt_vid_v: <value in [disable, enable]>
+          # act: <integer>
+          # act_v: <value in [disable, enable]>
+          # fmtuv4_s: <integer>
+          # fmtuv4_s_v: <value in [disable, enable]>
+          # fmtuv6_s: <integer>
+          # fmtuv6_s_v: <value in [disable, enable]>
+          # lnkid: <integer>
+          # lnkid_v: <value in [disable, enable]>
+          # mac_id: <integer>
+          # mac_id_v: <value in [disable, enable]>
+          # mss_t: <integer>
+          # mss_t_v: <value in [disable, enable]>
+          # mtuv4: <integer>
+          # mtuv4_v: <value in [disable, enable]>
+          # mtuv6: <integer>
+          # mtuv6_v: <value in [disable, enable]>
+          # slif_act: <integer>
+          # slif_act_v: <value in [disable, enable]>
+          # sublnkid: <integer>
+          # sublnkid_v: <value in [disable, enable]>
+          # tgtv_act: <integer>
+          # tgtv_act_v: <value in [disable, enable]>
+          # tlif_act: <integer>
+          # tlif_act_v: <value in [disable, enable]>
+          # tpeid: <integer>
+          # tpeid_v: <value in [disable, enable]>
+          # v6fe: <integer>
+          # v6fe_v: <value in [disable, enable]>
+          # vep_en_v: <value in [disable, enable]>
+          # vep_slid: <integer>
+          # vep_slid_v: <value in [disable, enable]>
+          # vep_en: <integer>
+          # xlt_lif: <integer>
+          # xlt_lif_v: <value in [disable, enable]>
+          # xlt_vid: <integer>
+          # xlt_vid_v: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -348,23 +376,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/npu/npu-tcam/{npu-tcam}/tact',
         '/pm/config/global/obj/system/npu/npu-tcam/{npu-tcam}/tact'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/npu/npu-tcam/{npu-tcam}/tact/{tact}',
-        '/pm/config/global/obj/system/npu/npu-tcam/{npu-tcam}/tact/{tact}'
-    ]
-
     url_params = ['adom', 'npu-tcam']
     module_primary_key = None
     module_arg_spec = {
@@ -412,7 +432,6 @@ def main():
                 'xlt-vid': {'v_range': [['7.4.2', '']], 'type': 'int'},
                 'xlt-vid-v': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -426,9 +445,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
