@@ -92,9 +92,10 @@ options:
             description:
                 type: str
                 description: Description.
-            modification-time:
+            modification_time:
+                aliases: ['modification-time']
                 type: str
-                description: Deprecated, please rename it to modification_time. Modification time.
+                description: Modification time.
             name:
                 type: str
                 description: Name.
@@ -151,17 +152,17 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         template:
-          description: <string>
-          modification_time: <string>
-          name: <string>
-          script: <string>
-          provision: <value in [disable, enable]>
-          type: <value in [cli, jinja]>
-          variables: <list or string>
-          position: <value in [post-vdom-copy, prep-vdom-copy]>
-          option:
-            - sdwan-overlay
-            - sdwan-manager
+          name: "your value" # Required variable, string
+          # description: <string>
+          # modification_time: <string>
+          # script: <string>
+          # provision: <value in [disable, enable]>
+          # type: <value in [cli, jinja]>
+          # variables: <list or string>
+          # position: <value in [post-vdom-copy, prep-vdom-copy]>
+          # option:
+          #   - "sdwan-overlay"
+          #   - "sdwan-manager"
 '''
 
 RETURN = '''
@@ -205,23 +206,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/cli/template',
         '/pm/config/global/obj/cli/template'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/cli/template/{template}',
-        '/pm/config/global/obj/cli/template/{template}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -240,7 +233,6 @@ def main():
                 'position': {'v_range': [['7.4.2', '']], 'choices': ['post-vdom-copy', 'prep-vdom-copy'], 'type': 'str'},
                 'option': {'v_range': [['7.6.0', '']], 'type': 'list', 'choices': ['sdwan-overlay', 'sdwan-manager'], 'elements': 'str'}
             }
-
         }
     }
 
@@ -254,9 +246,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
