@@ -187,23 +187,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/device-group/{device-group}/tagging',
         '/pm/config/global/obj/user/device-group/{device-group}/tagging'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/device-group/{device-group}/tagging/{tagging}',
-        '/pm/config/global/obj/user/device-group/{device-group}/tagging/{tagging}'
-    ]
-
     url_params = ['adom', 'device-group']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -218,7 +210,6 @@ def main():
                 'name': {'v_range': [['6.0.0', '7.2.1']], 'required': True, 'type': 'str'},
                 'tags': {'v_range': [['6.0.0', '7.2.1']], 'type': 'raw'}
             }
-
         }
     }
 
@@ -232,9 +223,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
