@@ -133,10 +133,10 @@ EXAMPLES = '''
         profile: <your own value>
         state: present # <value in [present, absent]>
         virtualpatch_profile_exemption:
-          device: <list or string>
-          id: <integer>
-          rule: <list or integer>
-          status: <value in [disable, enable]>
+          id: 0 # Required variable, integer
+          # device: <list or string>
+          # rule: <list or integer>
+          # status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -180,23 +180,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/virtual-patch/profile/{profile}/exemption',
         '/pm/config/global/obj/virtual-patch/profile/{profile}/exemption'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/virtual-patch/profile/{profile}/exemption/{exemption}',
-        '/pm/config/global/obj/virtual-patch/profile/{profile}/exemption/{exemption}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -211,7 +203,6 @@ def main():
                 'rule': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'int'},
                 'status': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -225,9 +216,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
