@@ -133,11 +133,11 @@ EXAMPLES = '''
         adom: <your own value>
         profile: <your own value>
         waf_profile_constraint_urlparamlength:
-          action: <value in [allow, block]>
-          length: <integer>
-          log: <value in [disable, enable]>
-          severity: <value in [low, medium, high]>
-          status: <value in [disable, enable]>
+          # action: <value in [allow, block]>
+          # length: <integer>
+          # log: <value in [disable, enable]>
+          # severity: <value in [low, medium, high]>
+          # status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -181,23 +181,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/waf/profile/{profile}/constraint/url-param-length',
         '/pm/config/global/obj/waf/profile/{profile}/constraint/url-param-length'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/waf/profile/{profile}/constraint/url-param-length/{url-param-length}',
-        '/pm/config/global/obj/waf/profile/{profile}/constraint/url-param-length/{url-param-length}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = None
     module_arg_spec = {
@@ -213,7 +205,6 @@ def main():
                 'severity': {'choices': ['low', 'medium', 'high'], 'type': 'str'},
                 'status': {'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -227,9 +218,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
