@@ -95,15 +95,17 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            group-down-option:
+            group_down_option:
+                aliases: ['group-down-option']
                 type: str
-                description: Deprecated, please rename it to group_down_option. Action to take when all of the servers in the forward server group are down
+                description: Action to take when all of the servers in the forward server group are down
                 choices:
                     - 'block'
                     - 'pass'
-            ldb-method:
+            ldb_method:
+                aliases: ['ldb-method']
                 type: str
-                description: Deprecated, please rename it to ldb_method. Load balance method
+                description: Load balance method
                 choices:
                     - 'weighted'
                     - 'least-session'
@@ -112,10 +114,11 @@ options:
                 type: str
                 description: Configure a forward server group consisting one or multiple forward servers.
                 required: true
-            server-list:
+            server_list:
+                aliases: ['server-list']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to server_list. Server list.
+                description: Server list.
                 suboptions:
                     name:
                         type: str
@@ -144,14 +147,13 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         webproxy_forwardservergroup:
-          affinity: <value in [disable, enable]>
-          group_down_option: <value in [block, pass]>
-          ldb_method: <value in [weighted, least-session, active-passive]>
-          name: <string>
-          server_list:
-            -
-              name: <string>
-              weight: <integer>
+          name: "your value" # Required variable, string
+          # affinity: <value in [disable, enable]>
+          # group_down_option: <value in [block, pass]>
+          # ldb_method: <value in [weighted, least-session, active-passive]>
+          # server_list:
+          #   - name: <string>
+          #     weight: <integer>
 '''
 
 RETURN = '''
@@ -195,23 +197,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/web-proxy/forward-server-group',
         '/pm/config/global/obj/web-proxy/forward-server-group'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/web-proxy/forward-server-group/{forward-server-group}',
-        '/pm/config/global/obj/web-proxy/forward-server-group/{forward-server-group}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -226,7 +220,6 @@ def main():
                 'name': {'required': True, 'type': 'str'},
                 'server-list': {'type': 'list', 'options': {'name': {'type': 'str'}, 'weight': {'type': 'int'}}, 'elements': 'dict'}
             }
-
         }
     }
 
@@ -240,9 +233,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
