@@ -1,7 +1,7 @@
 #!/usr/bin/python
 ''' This is an Ansible module for ONTAP, to manage initiators in an Igroup
 
- (c) 2019-2022, NetApp, Inc
+ (c) 2019-2025, NetApp, Inc
  # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 '''
 
@@ -60,25 +60,24 @@ options:
 '''
 
 EXAMPLES = '''
-    - name: Add initiators to an igroup
-      netapp.ontap.na_ontap_igroup_initiator:
-        names: abc.test:def.com,def.test:efg.com
-        initiator_group: test_group
-        vserver: ansibleVServer
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-
-    - name: Remove an initiator from an igroup
-      netapp.ontap.na_ontap_igroup_initiator:
-        state: absent
-        names: abc.test:def.com
-        initiator_group: test_group
-        vserver: ansibleVServer
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
+- name: Add initiators to an igroup
+  netapp.ontap.na_ontap_igroup_initiator:
+    names: abc.test:def.com,def.test:efg.com
+    initiator_group: test_group
+    vserver: ansibleVServer
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 
+- name: Remove an initiator from an igroup
+  netapp.ontap.na_ontap_igroup_initiator:
+    state: absent
+    names: abc.test:def.com
+    initiator_group: test_group
+    vserver: ansibleVServer
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
 '''
 
 RETURN = '''
@@ -192,7 +191,7 @@ class NetAppOntapIgroupInitiator(object):
             dummy, error = rest_generic.post_async(self.rest_api, api, body)
         else:
             query = {'allow_delete_while_mapped': self.parameters['force_remove']}
-            dummy, error = rest_generic.delete_async(self.rest_api, api, initiator_name, query)
+            dummy, error = rest_generic.delete_async(self.rest_api, api, initiator_name.lower(), query)
         if error:
             self.module.fail_json(msg="Error modifying igroup initiator %s: %s" % (initiator_name, error))
 
@@ -201,7 +200,7 @@ class NetAppOntapIgroupInitiator(object):
         for initiator in self.parameters['names']:
             present = None
             initiator = self.na_helper.sanitize_wwn(initiator)
-            if initiator in initiators:
+            if initiator.lower() in initiators:
                 present = True
             cd_action = self.na_helper.get_cd_action(present, self.parameters)
             if self.na_helper.changed and not self.module.check_mode:
@@ -209,7 +208,8 @@ class NetAppOntapIgroupInitiator(object):
                     self.modify_initiator(initiator, 'igroup-add')
                 elif cd_action == 'delete':
                     self.modify_initiator(initiator, 'igroup-remove')
-        self.module.exit_json(changed=self.na_helper.changed)
+        result = netapp_utils.generate_result(self.na_helper.changed, cd_action)
+        self.module.exit_json(**result)
 
 
 def main():
