@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2022-2023, NetApp, Inc
+# (c) 2022-2025, NetApp, Inc
 # GNU General Public License v3.0+
 # (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
@@ -12,7 +12,7 @@ DOCUMENTATION = '''
 module: na_ontap_s3_groups
 short_description: NetApp ONTAP S3 groups
 extends_documentation_fragment:
-    - netapp.ontap.netapp.na_ontap
+    - netapp.ontap.netapp.na_ontap_rest
 version_added: 21.21.0
 author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
 description:
@@ -63,36 +63,36 @@ options:
 '''
 
 EXAMPLES = """
-    - name: Create and modify a S3 Group
-      netapp.ontap.na_ontap_s3_groups:
-        state: present
-        name: dev-group
-        comment: group for devs
-        vserver: ansibleSVM
-        users:
-          - name: carchi8py
-          - name: carchi8py2
-        policies:
-          - name: allow_policy
-          - name: deny_policy
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        https: true
-        validate_certs: false
-        use_rest: always
+- name: Create and modify a S3 Group
+  netapp.ontap.na_ontap_s3_groups:
+    state: present
+    name: dev-group
+    comment: group for devs
+    vserver: ansibleSVM
+    users:
+      - name: carchi8py
+      - name: carchi8py2
+    policies:
+      - name: allow_policy
+      - name: deny_policy
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    https: true
+    validate_certs: false
+    use_rest: always
 
-    - name: Delete a S3 Group
-      netapp.ontap.na_ontap_s3_groups:
-        state: absent
-        name: dev-group
-        vserver: ansibleSVM
-        hostname: "{{ netapp_hostname }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        https: true
-        validate_certs: false
-        use_rest: always
+- name: Delete a S3 Group
+  netapp.ontap.na_ontap_s3_groups:
+    state: absent
+    name: dev-group
+    vserver: ansibleSVM
+    hostname: "{{ netapp_hostname }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    https: true
+    validate_certs: false
+    use_rest: always
 """
 
 RETURN = """
@@ -109,7 +109,7 @@ from ansible_collections.netapp.ontap.plugins.module_utils import rest_vserver
 
 class NetAppOntapS3Groups:
     def __init__(self):
-        self.argument_spec = netapp_utils.na_ontap_host_argument_spec()
+        self.argument_spec = netapp_utils.na_ontap_rest_only_spec()
         self.argument_spec.update(dict(
             state=dict(required=False, type='str', choices=['present', 'absent'], default='present'),
             vserver=dict(required=True, type='str'),
